(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[         0,          0]
NotebookDataLength[    204120,       5456]
NotebookOptionsPosition[    196437,       5319]
NotebookOutlinePosition[    196771,       5334]
CellTagsIndexPosition[    196728,       5331]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Derivation of regularized 13-moment equations for inverse power law models\
\>", "Title",
 CellChangeTimes->{{3.783984582206581*^9, 
  3.783984596290579*^9}},ExpressionUUID->"35865585-77d2-4c26-9220-\
59b2954ea8cc"],

Cell["\<\
Usage: Change the parameters in the first section, and then run the whole \
notebook.\
\>", "Subtitle",
 CellChangeTimes->{{3.783984620777792*^9, 
  3.78398464349629*^9}},ExpressionUUID->"4a972961-48c2-4909-bd05-\
2db5d26cc9a8"],

Cell[CellGroupData[{

Cell["Parameters", "Section",
 CellChangeTimes->{{3.782419650535108*^9, 
  3.78241965296323*^9}},ExpressionUUID->"a20515cf-e3bf-43e4-9c0d-\
a6757a2edae5"],

Cell["\<\
\[Eta] is the parameter for the inverse power law model, and Deg is the \
maximum degree involved in the expansion of the collision term.\
\>", "Text",
 CellChangeTimes->{
  3.783982614202238*^9},ExpressionUUID->"96590df2-57ee-4122-a7a5-\
dde79ffae33c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Eta]", "=", 
   RowBox[{"+", "\[Infinity]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Deg", "=", "20"}], ";"}]}], "Input",
 CellChangeTimes->{{3.782419655797501*^9, 3.782419681456668*^9}, {
  3.782472354604455*^9, 3.78247235487572*^9}, {3.782472800368991*^9, 
  3.782472803170637*^9}, {3.7839822840284*^9, 3.783982400719293*^9}, {
  3.783982617000952*^9, 3.783982617817363*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"a140609c-9d39-45f5-bdb0-9fb8016a4905"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic functions", "Section",
 CellChangeTimes->{{3.782383682673232*^9, 
  3.782383687158332*^9}},ExpressionUUID->"a66729af-2c0b-420b-9a6e-\
cf7f341e4da8"],

Cell["\<\
This section defines several fundamental functions to simplify the \
implementation.\
\>", "Text",
 CellChangeTimes->{{3.783982648087579*^9, 
  3.7839826622486343`*^9}},ExpressionUUID->"2c82af24-b88b-45d8-9ce7-\
1190cba18284"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", 
    RowBox[{"l_", ",", "m_", ",", "n_"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"l", "<", "0"}], "||", 
      RowBox[{"n", "<", "0"}], "||", 
      RowBox[{
       RowBox[{"Abs", "[", "m", "]"}], ">", "l"}], "||", 
      RowBox[{
       RowBox[{"l", "+", "n"}], "\[Equal]", "1"}]}], ",", "0", ",", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{"l", ",", "m", ",", "n"}]], "[", 
      RowBox[{
       SubscriptBox["x", "1"], ",", 
       SubscriptBox["x", "2"], ",", 
       SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", "\[Mu]_", "]"}], ":=", 
   RowBox[{"Switch", "[", 
    RowBox[{"\[Mu]", ",", "\[IndentingNewLine]", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["v", "1"], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{
          SubscriptBox["v", "2"], "[", 
          RowBox[{
           SubscriptBox["x", "1"], ",", 
           SubscriptBox["x", "2"], ",", 
           SubscriptBox["x", "3"], ",", "t"}], "]"}]}]}], ")"}]}], ",", 
     "\[IndentingNewLine]", "0", ",", 
     RowBox[{
      SubscriptBox["v", "3"], "[", 
      RowBox[{
       SubscriptBox["x", "1"], ",", 
       SubscriptBox["x", "2"], ",", 
       SubscriptBox["x", "3"], ",", "t"}], "]"}], ",", "\[IndentingNewLine]", 
     "1", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["v", "1"], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{
          SubscriptBox["v", "2"], "[", 
          RowBox[{
           SubscriptBox["x", "1"], ",", 
           SubscriptBox["x", "2"], ",", 
           SubscriptBox["x", "3"], ",", "t"}], "]"}]}]}], ")"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalTheta]", "=", 
   RowBox[{"\[Theta]", "[", 
    RowBox[{
     SubscriptBox["x", "1"], ",", 
     SubscriptBox["x", "2"], ",", 
     SubscriptBox["x", "3"], ",", "t"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Mu]", "=", 
   RowBox[{"\[Mu]0", " ", 
    SuperscriptBox[
     RowBox[{"\[Theta]", "[", 
      RowBox[{
       SubscriptBox["x", "1"], ",", 
       SubscriptBox["x", "2"], ",", 
       SubscriptBox["x", "3"], ",", "t"}], "]"}], 
     RowBox[{
      FractionBox["1", "2"], "+", 
      FractionBox["2", 
       RowBox[{"\[Eta]", "-", "1"}]]}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gamma", "[", 
    RowBox[{"l_", ",", "m_", ",", "\[Mu]_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"l", "+", 
         RowBox[{
          RowBox[{"KroneckerDelta", "[", 
           RowBox[{"1", ",", "\[Mu]"}], "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "m"}], "+", "1"}], ")"}]}], "-", "m"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "l"}], "+", "1"}], ")"}]}], ")"}]}], 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"l", "-", 
         RowBox[{
          RowBox[{"KroneckerDelta", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "\[Mu]"}], "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "m"}], "-", "1"}], ")"}]}], "+", "m"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "l"}], "-", "1"}], ")"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"D\[Mu]", "[", 
    RowBox[{"\[Mu]_", ",", "f_"}], "]"}], ":=", 
   RowBox[{"Switch", "[", 
    RowBox[{"\[Mu]", ",", "\[IndentingNewLine]", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", 
        SubscriptBox["x", "1"]], "f"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         SubscriptBox["x", "2"]], "f"}]}]}], ",", "\[IndentingNewLine]", "0", 
     ",", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       SubscriptBox["x", "3"]], "f"}], ",", "\[IndentingNewLine]", "1", ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         SubscriptBox["x", "1"]], "f"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         SubscriptBox["x", "2"]], "f"}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exprToFunction", "[", 
    RowBox[{"expr_", ",", "vars_"}], "]"}], ":=", 
   RowBox[{"Function", "[", 
    RowBox[{"Evaluate", "[", 
     RowBox[{"expr", "/.", 
      RowBox[{"Thread", "[", 
       RowBox[{"vars", "\[Rule]", 
        RowBox[{"Array", "[", 
         RowBox[{"Slot", ",", 
          RowBox[{"Length", "[", "vars", "]"}]}], "]"}]}], "]"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Idx", "[", 
    RowBox[{"l_", ",", "m_", ",", "n_"}], "]"}], ":=", 
   RowBox[{"Sequence", "[", 
    RowBox[{
     RowBox[{"l", "+", "1"}], ",", 
     RowBox[{"m", "+", "l", "+", "1"}], ",", 
     RowBox[{"n", "+", "1"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.782380323874847*^9, 3.782380396772644*^9}, {
  3.7823804325826197`*^9, 3.7823806090105877`*^9}, {3.782380641436364*^9, 
  3.7823808900771723`*^9}, {3.782383719181837*^9, 3.782383801354258*^9}, {
  3.782384256425261*^9, 3.782384291683363*^9}, {3.7824435024906588`*^9, 
  3.782443504305333*^9}, {3.782448119541873*^9, 3.782448119792255*^9}, {
  3.782512413912251*^9, 3.782512463452036*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"08cc1a2f-7b16-402e-b24e-0a2f718ebcae"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", 
    RowBox[{"l", ",", "m", ",", "n"}]], TraditionalForm]],ExpressionUUID->
  "1ff31bb3-aab3-4585-acc4-37422c24963f"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", 
    RowBox[{"l", ",", "m", ",", "n"}]], TraditionalForm]],ExpressionUUID->
  "ecc9ce4f-5d79-404e-8b3d-7d7ea075cfee"]
}], "Section",
 CellChangeTimes->{{3.782383583646337*^9, 3.782383595174553*^9}, {
  3.782383661448669*^9, 
  3.782383674874364*^9}},ExpressionUUID->"bb0b5523-a811-4b15-8323-\
b5e2d61b2056"],

Cell[TextData[{
 "Formulas for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", 
    RowBox[{"l", ",", "m", ",", "n"}]], TraditionalForm]],ExpressionUUID->
  "96ea3893-d122-46e8-91ca-5c24bc7b99c3"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", 
    RowBox[{"l", ",", "m", ",", "n"}]], TraditionalForm]],ExpressionUUID->
  "e35c7c14-6315-412e-967d-ea30d57a399d"],
 ". See equations (B.4) and (B.7)."
}], "Text",
 CellChangeTimes->{{3.783982680942562*^9, 3.7839826936425447`*^9}, {
  3.7839827334789124`*^9, 
  3.78398273787177*^9}},ExpressionUUID->"3851b178-07af-4768-bf4b-\
610e3d063db6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"S", "[", 
    RowBox[{"l_", ",", "m_", ",", "n_"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"l", "<", "0"}], "||", 
      RowBox[{"n", "<", "0"}], "||", 
      RowBox[{
       RowBox[{"Abs", "[", "m", "]"}], ">", "l"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SqrtBox[
         RowBox[{"n", 
          RowBox[{"(", 
           RowBox[{"n", "+", "l", "+", 
            RowBox[{"1", "/", "2"}]}], ")"}]}]]}], 
       RowBox[{
        SubscriptBox["\[PartialD]", "t"], "\[CapitalTheta]"}], " ", 
       RowBox[{"F", "[", 
        RowBox[{"l", ",", "m", ",", 
         RowBox[{"n", "-", "1"}]}], "]"}]}], "+", 
      RowBox[{
       SqrtBox["2"], 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"\[Mu]", "=", 
          RowBox[{"-", "1"}]}], "1"], 
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", "t"], 
          RowBox[{"V", "[", "\[Mu]", "]"}]}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "\[Mu]"], 
            SqrtBox[
             RowBox[{"n", "+", "l", "+", 
              RowBox[{"1", "/", "2"}]}]], 
            RowBox[{"gamma", "[", 
             RowBox[{"l", ",", 
              RowBox[{"m", "+", "\[Mu]"}], ",", 
              RowBox[{"-", "\[Mu]"}]}], "]"}], 
            RowBox[{"F", "[", 
             RowBox[{
              RowBox[{"l", "-", "1"}], ",", 
              RowBox[{"m", "+", "\[Mu]"}], ",", "n"}], "]"}]}], "-", 
           RowBox[{
            SqrtBox["n"], 
            RowBox[{"gamma", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "l"}], "-", "1"}], ",", 
              RowBox[{"m", "+", "\[Mu]"}], ",", 
              RowBox[{"-", "\[Mu]"}]}], "]"}], 
            RowBox[{"F", "[", 
             RowBox[{
              RowBox[{"l", "+", "1"}], ",", 
              RowBox[{"m", "+", "\[Mu]"}], ",", 
              RowBox[{"n", "-", "1"}]}], "]"}]}]}], ")"}]}]}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FF", "[", 
    RowBox[{"l_", ",", "m_", ",", "n_", ",", "\[Mu]_"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"l", "<", "0"}], "||", 
      RowBox[{"n", "<", "0"}], "||", 
      RowBox[{
       RowBox[{"Abs", "[", "m", "]"}], ">", "l"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"D\[Mu]", "[", 
       RowBox[{"\[Mu]", ",", 
        RowBox[{"F", "[", 
         RowBox[{"l", ",", "m", ",", "n"}], "]"}]}], "]"}], "-", 
      RowBox[{
       SqrtBox[
        RowBox[{"n", 
         RowBox[{"(", 
          RowBox[{"n", "+", "l", "+", 
           RowBox[{"1", "/", "2"}]}], ")"}]}]], 
       RowBox[{"D\[Mu]", "[", 
        RowBox[{"\[Mu]", ",", "\[CapitalTheta]"}], "]"}], 
       RowBox[{"F", "[", 
        RowBox[{"l", ",", "m", ",", 
         RowBox[{"n", "-", "1"}]}], "]"}]}], "+", 
      RowBox[{
       SqrtBox["2"], 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"\[Nu]", "=", 
          RowBox[{"-", "1"}]}], "1"], 
        RowBox[{
         RowBox[{"D\[Mu]", "[", 
          RowBox[{"\[Mu]", ",", 
           RowBox[{"V", "[", "\[Nu]", "]"}]}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "\[Nu]"], 
            SqrtBox[
             RowBox[{"n", "+", "l", "+", 
              RowBox[{"1", "/", "2"}]}]], 
            RowBox[{"gamma", "[", 
             RowBox[{"l", ",", 
              RowBox[{"m", "+", "\[Nu]"}], ",", 
              RowBox[{"-", "\[Nu]"}]}], "]"}], 
            RowBox[{"F", "[", 
             RowBox[{
              RowBox[{"l", "-", "1"}], ",", 
              RowBox[{"m", "+", "\[Nu]"}], ",", "n"}], "]"}]}], "-", 
           RowBox[{
            SqrtBox["n"], 
            RowBox[{"gamma", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "l"}], "-", "1"}], ",", 
              RowBox[{"m", "+", "\[Nu]"}], ",", 
              RowBox[{"-", "\[Nu]"}]}], "]"}], 
            RowBox[{"F", "[", 
             RowBox[{
              RowBox[{"l", "+", "1"}], ",", 
              RowBox[{"m", "+", "\[Nu]"}], ",", 
              RowBox[{"n", "-", "1"}]}], "]"}]}]}], ")"}]}]}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"l_", ",", "m_", ",", "n_"}], "]"}], ":=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"\[Mu]", "=", 
      RowBox[{"-", "1"}]}], "1"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"V", "[", "\[Mu]", "]"}], 
       RowBox[{"FF", "[", 
        RowBox[{"l", ",", "m", ",", "n", ",", "\[Mu]"}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox["2", 
         RowBox[{"Abs", "[", "\[Mu]", "]"}]]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SqrtBox[
           RowBox[{
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{"n", "+", "l"}], ")"}]}], "+", "1"}]], 
          RowBox[{"gamma", "[", 
           RowBox[{"l", ",", 
            RowBox[{"m", "-", "\[Mu]"}], ",", "\[Mu]"}], "]"}], 
          "\[CapitalTheta]", " ", 
          RowBox[{"FF", "[", 
           RowBox[{
            RowBox[{"l", "-", "1"}], ",", 
            RowBox[{"m", "-", "\[Mu]"}], ",", "n", ",", "\[Mu]"}], "]"}]}], 
         "-", 
         RowBox[{
          SqrtBox[
           RowBox[{"2", 
            RowBox[{"(", 
             RowBox[{"n", "+", "1"}], ")"}]}]], 
          RowBox[{"gamma", "[", 
           RowBox[{"l", ",", 
            RowBox[{"m", "-", "\[Mu]"}], ",", "\[Mu]"}], "]"}], 
          RowBox[{"FF", "[", 
           RowBox[{
            RowBox[{"l", "-", "1"}], ",", 
            RowBox[{"m", "-", "\[Mu]"}], ",", 
            RowBox[{"n", "+", "1"}], ",", "\[Mu]"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "\[Mu]"], 
          RowBox[{"gamma", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "l"}], "-", "1"}], ",", 
            RowBox[{"m", "-", "\[Mu]"}], ",", "\[Mu]"}], "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox[
              RowBox[{
               RowBox[{"2", 
                RowBox[{"(", 
                 RowBox[{"n", "+", "l"}], ")"}]}], "+", "3"}]], 
             RowBox[{"FF", "[", 
              RowBox[{
               RowBox[{"l", "+", "1"}], ",", 
               RowBox[{"m", "-", "\[Mu]"}], ",", "n", ",", "\[Mu]"}], "]"}]}],
             "-", 
            RowBox[{
             SqrtBox[
              RowBox[{"2", "n"}]], "\[CapitalTheta]", " ", 
             RowBox[{"FF", "[", 
              RowBox[{
               RowBox[{"l", "+", "1"}], ",", 
               RowBox[{"m", "-", "\[Mu]"}], ",", 
               RowBox[{"n", "-", "1"}], ",", "\[Mu]"}], "]"}]}]}], ")"}]}]}], 
        ")"}]}]}], ")"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.782383809101701*^9, 3.7823842474066887`*^9}, {
  3.782443200128282*^9, 3.782443200865406*^9}, {3.7824434988764687`*^9, 
  3.782443499100587*^9}, {3.782470469506661*^9, 3.7824704696208963`*^9}, {
  3.7824705130384607`*^9, 3.782470517856564*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"bb9287e9-b64e-4673-9b97-d21bf520a1da"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate coefficients for the linearized collision term", "Section",
 CellChangeTimes->{{3.7824193978425293`*^9, 3.782419401354162*^9}, {
  3.782712548491159*^9, 
  3.782712555096835*^9}},ExpressionUUID->"11d9809b-e0e7-4f50-8bb6-\
72578920e083"],

Cell[TextData[{
 "This part computes the coefficients in the expansion of the linearized \
collision term as implemented in [Z. Cai and M. Torrilhon, ",
 StyleBox["Approximation of the linearized Boltzmann collision operator for \
hard-sphere and inverse-power-law models",
  FontSlant->"Italic"],
 ", J. Comput. Phys. 295 (2015), pp. 617--643]. Running this whole section \
may take several minutes."
}], "Text",
 CellChangeTimes->{{3.783982424503173*^9, 
  3.783982587222385*^9}},ExpressionUUID->"4949c295-f853-48eb-a1e8-\
6cfec7a23197"],

Cell[CellGroupData[{

Cell[TextData[{
 "Expansion of the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["Q", 
     RowBox[{"l", " ", "m", " ", "n"}]], "(", 
    RowBox[{"h", "+", 
     RowBox[{
      FractionBox["1", "2"], "g"}]}], ")"}], TraditionalForm]],ExpressionUUID->
  "a1e2a3c7-ccf7-44ec-92f5-14b87bd2c877"]
}], "Subsection",
 CellChangeTimes->{
  3.782419414758843*^9},ExpressionUUID->"832ccca0-7855-442a-b680-\
b4dd774c1661"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "0", ",", "Deg"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", 
       RowBox[{"Floor", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Deg", "-", "l"}], ")"}], "/", "2"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"l1", ",", "0", ",", 
       RowBox[{"l", "+", "n"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n1", ",", "0", ",", 
       RowBox[{"Min", "[", 
        RowBox[{
         RowBox[{"2", "n"}], ",", 
         RowBox[{"Floor", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"l", "-", "l1"}], ")"}], "/", "2"}], "+", "n"}], "]"}]}],
         "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n2", ",", 
       RowBox[{"Max", "[", 
        RowBox[{"0", ",", 
         RowBox[{"Ceiling", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"n", "-", "l1"}], ")"}], "/", "2"}], "-", "n1"}], 
          "]"}]}], "]"}], ",", 
       RowBox[{"Min", "[", 
        RowBox[{
         RowBox[{"2", "n"}], ",", 
         RowBox[{"Floor", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"l", "-", "l1"}], ")"}], "/", "2"}], "+", "n", "-", 
           "n1"}], "]"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m1", ",", 
       RowBox[{"Max", "[", 
        RowBox[{
         RowBox[{"-", "l1"}], ",", 
         RowBox[{"l1", "-", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{"n", "-", "n1", "-", "n2"}], ")"}]}]}]}], "]"}], ",", 
       RowBox[{"Min", "[", 
        RowBox[{"l1", ",", 
         RowBox[{
          RowBox[{"2", "l"}], "-", "l1", "+", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{"n", "-", "n1", "-", "n2"}], ")"}]}]}]}], "]"}]}], 
      "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GetA", "[", 
    RowBox[{
    "l_Integer", ",", "n_Integer", ",", "l1_Integer", ",", "m1_Integer", ",", 
     "n1_Integer", ",", "n2_Integer"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dn", ",", "dm"}], "}"}], ",", 
     RowBox[{
      RowBox[{"dn", "=", 
       RowBox[{"n2", "-", 
        RowBox[{"Max", "[", 
         RowBox[{"0", ",", 
          RowBox[{"Ceiling", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"n", "-", "l1"}], ")"}], "/", "2"}], "-", "n1"}], 
           "]"}]}], "]"}]}]}], ";", 
      RowBox[{"dm", "=", 
       RowBox[{"m1", "-", 
        RowBox[{"Max", "[", 
         RowBox[{
          RowBox[{"-", "l1"}], ",", 
          RowBox[{"l1", "-", 
           RowBox[{"2", 
            RowBox[{"(", 
             RowBox[{"n", "-", "n1", "-", "n2"}], ")"}]}]}]}], "]"}]}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"l", "\[GreaterEqual]", "0"}], "&&", 
         RowBox[{"l", "<", 
          RowBox[{"Length", "[", "A", "]"}]}], "&&", 
         RowBox[{"n", "\[GreaterEqual]", "0"}], "&&", 
         RowBox[{"n", "<", 
          RowBox[{"Length", "[", 
           RowBox[{"A", "\[LeftDoubleBracket]", 
            RowBox[{"l", "+", "1"}], "\[RightDoubleBracket]"}], "]"}]}], "&&", 
         RowBox[{"l1", "\[GreaterEqual]", "0"}], "&&", 
         RowBox[{"l1", "<", 
          RowBox[{"Length", "[", 
           RowBox[{"A", "\[LeftDoubleBracket]", 
            RowBox[{
             RowBox[{"l", "+", "1"}], ",", 
             RowBox[{"n", "+", "1"}]}], "\[RightDoubleBracket]"}], "]"}]}], "&&", 
         RowBox[{"n1", "\[GreaterEqual]", "0"}], "&&", 
         RowBox[{"n1", "<", 
          RowBox[{"Length", "[", 
           RowBox[{"A", "\[LeftDoubleBracket]", 
            RowBox[{
             RowBox[{"l", "+", "1"}], ",", 
             RowBox[{"n", "+", "1"}], ",", 
             RowBox[{"l1", "+", "1"}]}], "\[RightDoubleBracket]"}], "]"}]}], "&&", 
         RowBox[{"dn", "\[GreaterEqual]", "0"}], "&&", 
         RowBox[{"dn", "<", 
          RowBox[{"Length", "[", 
           RowBox[{"A", "\[LeftDoubleBracket]", 
            RowBox[{
             RowBox[{"l", "+", "1"}], ",", 
             RowBox[{"n", "+", "1"}], ",", 
             RowBox[{"l1", "+", "1"}], ",", 
             RowBox[{"n1", "+", "1"}]}], "\[RightDoubleBracket]"}], "]"}]}], "&&", 
         RowBox[{"dm", "\[GreaterEqual]", "0"}], "&&", 
         RowBox[{"dm", "<", 
          RowBox[{"Length", "[", 
           RowBox[{"A", "\[LeftDoubleBracket]", 
            RowBox[{
             RowBox[{"l", "+", "1"}], ",", 
             RowBox[{"n", "+", "1"}], ",", 
             RowBox[{"l1", "+", "1"}], ",", 
             RowBox[{"n1", "+", "1"}], ",", 
             RowBox[{"dn", "+", "1"}]}], "\[RightDoubleBracket]"}], "]"}]}]}],
         ",", 
        RowBox[{"A", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"l", "+", "1"}], ",", 
          RowBox[{"n", "+", "1"}], ",", 
          RowBox[{"l1", "+", "1"}], ",", 
          RowBox[{"n1", "+", "1"}], ",", 
          RowBox[{"dn", "+", "1"}], ",", 
          RowBox[{"dm", "+", "1"}]}], "\[RightDoubleBracket]"}], ",", "0"}], 
       "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SetA", "[", 
    RowBox[{
    "l_Integer", ",", "n_Integer", ",", "l1_Integer", ",", "m1_Integer", ",", 
     "n1_Integer", ",", "n2_Integer", ",", "x_"}], "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"A", "\[LeftDoubleBracket]", 
      RowBox[{
       RowBox[{"l", "+", "1"}], ",", 
       RowBox[{"n", "+", "1"}], ",", 
       RowBox[{"l1", "+", "1"}], ",", 
       RowBox[{"n1", "+", "1"}], ",", 
       RowBox[{"n2", "-", 
        RowBox[{"Max", "[", 
         RowBox[{"0", ",", 
          RowBox[{"Ceiling", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"n", "-", "l1"}], ")"}], "/", "2"}], "-", "n1"}], 
           "]"}]}], "]"}], "+", "1"}], ",", 
       RowBox[{"m1", "-", 
        RowBox[{"Max", "[", 
         RowBox[{
          RowBox[{"-", "l1"}], ",", 
          RowBox[{"l1", "-", 
           RowBox[{"2", 
            RowBox[{"(", 
             RowBox[{"n", "-", "n1", "-", "n2"}], ")"}]}]}]}], "]"}], "+", 
        "1"}]}], "\[RightDoubleBracket]"}], "=", "x"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Gam", "[", 
    RowBox[{"l_", ",", "m_", ",", "\[Mu]_"}], "]"}], ":=", 
   RowBox[{"\[Sqrt]", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"Abs", "[", "\[Mu]", "]"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "l"}], "-", "1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "l"}], "+", "1"}], ")"}]}]], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"l", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", 
             RowBox[{"KroneckerDelta", "[", 
              RowBox[{"1", ",", "\[Mu]"}], "]"}]}], "-", "1"}], ")"}], "m"}], 
         "+", 
         RowBox[{"KroneckerDelta", "[", 
          RowBox[{"1", ",", "\[Mu]"}], "]"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"l", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", 
             RowBox[{"KroneckerDelta", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "\[Mu]"}], "]"}]}], "-", "1"}], ")"}],
           "m"}], "+", 
         RowBox[{"KroneckerDelta", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "\[Mu]"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGBQBmIQ3ZiziN+O6bXj3Kea4iCaJ/yaPIieF8qiA6JNioIM
QLR69HILEP3nWp0TiPY7yB8Gon83a/50BtIhb6rBNM/UrVKuQLqmpEkGRL+a
Uq0IokP+2CiBaJX7DVogmintahqI7lq1fDKIFv6wYQ6InhBwhsUdSNtlJoqA
6NUb9SVBtMECAWkQnTNfWRFEf0ydpAmiOc60WIDoT5vueYBo8eS8zR4g81PL
wPS5QDtLTyDt1hoBpn9nbtH3AtIXz+4G0zI1B9JAdEPLBTBddo+xAUQ7tXOB
aTfzrHeJQFriay+YbvqmLZMMpCtmFciB6BO1progOsLMyRhEbyqQMwfRTh0/
wPRtNWMnEP1lqqUziH72fWEsiL5etTcRRK9be6UZRL+IfAmmG57MmZMCpNVi
F4FpvrMeV0B0gNfdayD616MFL0H0QqFNYLrmkdB7EK3PKQqmz+yU5/9u9tox
b0scmM55V3ic0fy1o3HVbTDtq/9tZo0F0L1cXLNAdIs8p3Xm+deOocoqYFrT
7sirZL03jivCr4HpwMlAdwDpgr3LwTQAqmTzdg==
  "],
 CellLabel->"In[14]:=",ExpressionUUID->"5828cf1c-362f-42ef-a902-4933bedf82ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"l", "=", "0"}], ",", 
    RowBox[{"l", "\[LessEqual]", "Deg"}], ",", 
    RowBox[{"l", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"l1", "=", "0"}], ",", 
       RowBox[{"l1", "\[LessEqual]", "l"}], ",", 
       RowBox[{"l1", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"SetA", "[", 
        RowBox[{
        "l", ",", "0", ",", "l1", ",", "l1", ",", "0", ",", "0", ",", 
         RowBox[{"N", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{
              RowBox[{"-", "l"}], "/", "2"}]], 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox["4", "\[Pi]"], ")"}], 
             RowBox[{"1", "/", "4"}]], 
            SqrtBox[
             RowBox[{"Binomial", "[", 
              RowBox[{
               RowBox[{"2", "l"}], ",", 
               RowBox[{"2", "l1"}]}], "]"}]], 
            SqrtBox[
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", "l"}], "+", "1"}], ")"}], 
               RowBox[{"Gamma", "[", 
                RowBox[{"l1", "+", 
                 RowBox[{"3", "/", "2"}]}], "]"}], 
               RowBox[{"Gamma", "[", 
                RowBox[{"l", "-", "l1", "+", 
                 RowBox[{"3", "/", "2"}]}], "]"}]}], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", "l1"}], "+", "1"}], ")"}], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", 
                  RowBox[{"(", 
                   RowBox[{"l", "-", "l1"}], ")"}]}], "+", "1"}], ")"}], 
               RowBox[{"Gamma", "[", 
                RowBox[{"l", "+", 
                 RowBox[{"3", "/", "2"}]}], "]"}]}]]]}], ",", "40"}], "]"}]}],
         "]"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"n", "=", "1"}], ",", 
       RowBox[{"n", "\[LessEqual]", 
        RowBox[{"Floor", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Deg", "-", "l"}], ")"}], "/", "2"}], "]"}]}], ",", 
       RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"l1", "=", "0"}], ",", 
         RowBox[{"l1", "\[LessEqual]", 
          RowBox[{"l", "+", "n"}]}], ",", 
         RowBox[{"l1", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{"For", "[", 
          RowBox[{
           RowBox[{"n1", "=", "0"}], ",", 
           RowBox[{"n1", "\[LessEqual]", 
            RowBox[{"Min", "[", 
             RowBox[{
              RowBox[{"2", "n"}], ",", 
              RowBox[{"Floor", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"l", "-", "l1"}], ")"}], "/", "2"}], "+", "n"}], 
               "]"}]}], "]"}]}], ",", 
           RowBox[{"n1", "++"}], ",", "\[IndentingNewLine]", 
           RowBox[{"For", "[", 
            RowBox[{
             RowBox[{"n2", "=", 
              RowBox[{"Max", "[", 
               RowBox[{"0", ",", 
                RowBox[{"Ceiling", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "-", "l1"}], ")"}], "/", "2"}], "-", "n1"}], 
                 "]"}]}], "]"}]}], ",", 
             RowBox[{"n2", "\[LessEqual]", 
              RowBox[{"Min", "[", 
               RowBox[{
                RowBox[{"2", "n"}], ",", 
                RowBox[{"Floor", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"l", "-", "l1"}], ")"}], "/", "2"}], "+", "n", 
                  "-", "n1"}], "]"}]}], "]"}]}], ",", 
             RowBox[{"n2", "++"}], ",", "\[IndentingNewLine]", 
             RowBox[{"For", "[", 
              RowBox[{
               RowBox[{"m1", "=", 
                RowBox[{"Max", "[", 
                 RowBox[{
                  RowBox[{"-", "l1"}], ",", 
                  RowBox[{"l1", "-", 
                   RowBox[{"2", 
                    RowBox[{"(", 
                    RowBox[{"n", "-", "n1", "-", "n2"}], ")"}]}]}]}], "]"}]}],
                ",", 
               RowBox[{"m1", "\[LessEqual]", 
                RowBox[{"Min", "[", 
                 RowBox[{"l1", ",", 
                  RowBox[{
                   RowBox[{"2", "l"}], "-", "l1", "+", 
                   RowBox[{"2", 
                    RowBox[{"(", 
                    RowBox[{"n", "-", "n1", "-", "n2"}], ")"}]}]}]}], "]"}]}],
                ",", 
               RowBox[{"m1", "++"}], ",", "\[IndentingNewLine]", 
               RowBox[{"SetA", "[", 
                RowBox[{
                "l", ",", "n", ",", "l1", ",", "m1", ",", "n1", ",", "n2", 
                 ",", 
                 RowBox[{"Module", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"l2", ",", "m2"}], "}"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"l2", "=", 
                    RowBox[{
                    RowBox[{"2", 
                    RowBox[{"(", 
                    RowBox[{"n", "-", "n1", "-", "n2"}], ")"}]}], "+", "l", 
                    "-", "l1"}]}], ";", "\[IndentingNewLine]", 
                    RowBox[{"m2", "=", 
                    RowBox[{"l", "-", "m1"}]}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"n", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "l", "+", 
                    RowBox[{"1", "/", "2"}]}], ")"}]}]]], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    SqrtBox[
                    RowBox[{"n1", 
                    RowBox[{"(", 
                    RowBox[{"n1", "+", "l1", "+", 
                    RowBox[{"1", "/", "2"}]}], ")"}]}]], "2"], 
                    RowBox[{"GetA", "[", 
                    RowBox[{"l", ",", 
                    RowBox[{"n", "-", "1"}], ",", "l1", ",", "m1", ",", 
                    RowBox[{"n1", "-", "1"}], ",", "n2"}], "]"}]}], "+", 
                    RowBox[{
                    FractionBox[
                    SqrtBox[
                    RowBox[{"n2", 
                    RowBox[{"(", 
                    RowBox[{"n2", "+", "l2", "+", 
                    RowBox[{"1", "/", "2"}]}], ")"}]}]], "2"], 
                    RowBox[{"GetA", "[", 
                    RowBox[{"l", ",", 
                    RowBox[{"n", "-", "1"}], ",", "l1", ",", "m1", ",", "n1", 
                    ",", 
                    RowBox[{"n2", "-", "1"}]}], "]"}]}], "-", 
                    RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                    RowBox[{"\[Mu]", "=", 
                    RowBox[{"-", "1"}]}], "1"], 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "\[Mu]"], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SqrtBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l1", "+", "n1", "+", 
                    RowBox[{"1", "/", "2"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"l2", "+", "n2", "+", 
                    RowBox[{"1", "/", "2"}]}], ")"}]}]], 
                    RowBox[{"Gam", "[", 
                    RowBox[{"l1", ",", 
                    RowBox[{"m1", "-", "\[Mu]"}], ",", "\[Mu]"}], "]"}], 
                    RowBox[{"Gam", "[", 
                    RowBox[{"l2", ",", 
                    RowBox[{"m2", "+", "\[Mu]"}], ",", 
                    RowBox[{"-", "\[Mu]"}]}], "]"}], 
                    RowBox[{"GetA", "[", 
                    RowBox[{"l", ",", 
                    RowBox[{"n", "-", "1"}], ",", 
                    RowBox[{"l1", "-", "1"}], ",", 
                    RowBox[{"m1", "-", "\[Mu]"}], ",", "n1", ",", "n2"}], 
                    "]"}]}], "-", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "\[Mu]"], 
                    SqrtBox[
                    RowBox[{"n1", 
                    RowBox[{"(", 
                    RowBox[{"l2", "+", "n2", "+", 
                    RowBox[{"1", "/", "2"}]}], ")"}]}]], 
                    RowBox[{"Gam", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "l1"}], "-", "1"}], ",", 
                    RowBox[{"m1", "-", "\[Mu]"}], ",", "\[Mu]"}], "]"}], 
                    RowBox[{"Gam", "[", 
                    RowBox[{"l2", ",", 
                    RowBox[{"m2", "+", "\[Mu]"}], ",", 
                    RowBox[{"-", "\[Mu]"}]}], "]"}], 
                    RowBox[{"GetA", "[", 
                    RowBox[{"l", ",", 
                    RowBox[{"n", "-", "1"}], ",", 
                    RowBox[{"l1", "+", "1"}], ",", 
                    RowBox[{"m1", "-", "\[Mu]"}], ",", 
                    RowBox[{"n1", "-", "1"}], ",", "n2"}], "]"}]}], "-", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "\[Mu]"], 
                    SqrtBox[
                    RowBox[{"n2", 
                    RowBox[{"(", 
                    RowBox[{"l1", "+", "n1", "+", 
                    RowBox[{"1", "/", "2"}]}], ")"}]}]], 
                    RowBox[{"Gam", "[", 
                    RowBox[{"l1", ",", 
                    RowBox[{"m1", "-", "\[Mu]"}], ",", "\[Mu]"}], "]"}], 
                    RowBox[{"Gam", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "l2"}], "-", "1"}], ",", 
                    RowBox[{"m2", "+", "\[Mu]"}], ",", 
                    RowBox[{"-", "\[Mu]"}]}], "]"}], 
                    RowBox[{"GetA", "[", 
                    RowBox[{"l", ",", 
                    RowBox[{"n", "-", "1"}], ",", 
                    RowBox[{"l1", "-", "1"}], ",", 
                    RowBox[{"m1", "-", "\[Mu]"}], ",", "n1", ",", 
                    RowBox[{"n2", "-", "1"}]}], "]"}]}], "+", 
                    RowBox[{
                    SqrtBox[
                    RowBox[{"n1", " ", "n2"}]], 
                    RowBox[{"Gam", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "l1"}], "-", "1"}], ",", 
                    RowBox[{"m1", "-", "\[Mu]"}], ",", "\[Mu]"}], "]"}], 
                    RowBox[{"Gam", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "l2"}], "-", "1"}], ",", 
                    RowBox[{"m2", "+", "\[Mu]"}], ",", 
                    RowBox[{"-", "\[Mu]"}]}], "]"}], 
                    RowBox[{"GetA", "[", 
                    RowBox[{"l", ",", 
                    RowBox[{"n", "-", "1"}], ",", 
                    RowBox[{"l1", "+", "1"}], ",", 
                    RowBox[{"m1", "-", "\[Mu]"}], ",", 
                    RowBox[{"n1", "-", "1"}], ",", 
                    RowBox[{"n2", "-", "1"}]}], "]"}]}]}], ")"}]}]}]}], 
                    "\[IndentingNewLine]", ")"}]}]}]}], "\[IndentingNewLine]",
                   "]"}]}], "\[IndentingNewLine]", "]"}]}], 
              "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
          "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
      "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQBGIQzXNv6nV3pteODltW3gDRAsJ3H4LoTY3KH0H04eOM
P0F0QFItiweQzpp8kQNEzzt/RghEq5YvEQPRSZH/FUF0iPdSLRD9h+8pmA7e
t9QQRBfNWmgPot+obYkD0RH6XIUgWi1csQlET7pxbzaI1qlbvwpELzq3fCOI
1tMTuACiZRwUwbT3Fx8DTyD9YkIimA4pZs/wAtI7+laDaakczxYQHbblXzuI
5u9hcUsG0k8+cYHpNI/cZDDN/gFMV11aaNQOpNmX3QPTvnZMDiA6xtYGQod4
xoDlz7eD6WW7hfMEmF87tnU7g2kWrUWPpYH0n+3XwfStbTvm11i8dlzXfRBM
n3v6OrlG742jzWGOTBA9q9O3G0SfCUwE00JeZRviDd84XpJtAtMA1mCtVw==

  "],
 CellLabel->"In[18]:=",ExpressionUUID->"869298bb-6eef-4119-9976-5657b3385d42"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Generate matrix from parameter ",
 Cell[BoxData[
  FormBox["\[Eta]", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "e643e046-02c6-4352-841f-8a6810362009"]
}], "Subsection",
 CellChangeTimes->{{3.782419438170989*^9, 
  3.782419446664414*^9}},ExpressionUUID->"dd409798-f00e-418c-93a9-\
c6dc37e2ef23"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GenerateMatrix", "[", "\[Eta]_", "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"\[Eta]", "\[Equal]", 
      RowBox[{"+", "\[Infinity]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"LagInt", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{"n2", "+", "n2p"}]], 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"n2", "!"}], 
             RowBox[{"n2p", "!"}]}], 
            RowBox[{
             RowBox[{"Gamma", "[", 
              RowBox[{"n2", "+", "l2", "+", 
               RowBox[{"3", "/", "2"}]}], "]"}], 
             RowBox[{"Gamma", "[", 
              RowBox[{"n2p", "+", "l2", "+", 
               RowBox[{"3", "/", "2"}]}], "]"}]}]]], 
          RowBox[{"Gamma", "[", 
           RowBox[{"l2", "+", "2"}], "]"}], 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "0"}], 
            RowBox[{"Min", "[", 
             RowBox[{"n2", ",", "n2p"}], "]"}]], 
           RowBox[{
            RowBox[{"Binomial", "[", 
             RowBox[{
              RowBox[{"1", "/", "2"}], ",", 
              RowBox[{"n2", "-", "k"}]}], "]"}], 
            RowBox[{"Binomial", "[", 
             RowBox[{
              RowBox[{"1", "/", "2"}], ",", 
              RowBox[{"n2p", "-", "k"}]}], "]"}], 
            RowBox[{"Binomial", "[", 
             RowBox[{
              RowBox[{"k", "+", "l2", "+", "1"}], ",", "k"}], "]"}]}]}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"l2", ",", "0", ",", "Deg"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n2", ",", "0", ",", 
           RowBox[{"Floor", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"Deg", "-", "l2"}], ")"}], "/", "2"}], "]"}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"n2p", ",", "0", ",", 
           RowBox[{"Floor", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"Deg", "-", "l2"}], ")"}], "/", "2"}], "]"}]}], "}"}]}],
         "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"a", "=", 
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"l", ",", "0", ",", "Deg"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", 
           RowBox[{"Floor", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"Deg", "-", "l"}], ")"}], "/", "2"}], "]"}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"np", ",", "0", ",", 
           RowBox[{"Floor", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"Deg", "-", "l"}], ")"}], "/", "2"}], "]"}]}], "}"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"l", "=", "0"}], ",", 
        RowBox[{"l", "\[LessEqual]", "Deg"}], ",", 
        RowBox[{"l", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"n", "=", "0"}], ",", 
          RowBox[{"n", "\[LessEqual]", 
           RowBox[{"Floor", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"Deg", "-", "l"}], ")"}], "/", "2"}], "]"}]}], ",", 
          RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"np", "=", "n"}], ",", 
            RowBox[{"np", "\[LessEqual]", 
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"Deg", "-", "l"}], ")"}], "/", "2"}], "]"}]}], ",", 
            RowBox[{"np", "++"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"a", "\[LeftDoubleBracket]", 
               RowBox[{
                RowBox[{"l", "+", "1"}], ",", 
                RowBox[{"n", "+", "1"}], ",", 
                RowBox[{"np", "+", "1"}]}], "\[RightDoubleBracket]"}], "=", 
              RowBox[{"4", "\[Pi]", 
               RowBox[{
                UnderoverscriptBox["\[Sum]", 
                 RowBox[{"l1", "=", "0"}], 
                 RowBox[{"l", "+", "n"}]], 
                RowBox[{
                 UnderoverscriptBox["\[Sum]", 
                  RowBox[{"n1", "=", "0"}], 
                  RowBox[{"Min", "[", 
                   RowBox[{
                    RowBox[{"2", "n"}], ",", 
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l", "-", "l1"}], ")"}], "/", "2"}], "+", "n"}], 
                    "]"}]}], "]"}]], 
                 RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                   RowBox[{"n2", "=", 
                    RowBox[{"Max", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"Ceiling", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "-", "l1"}], ")"}], "/", "2"}], "-", "n1"}], 
                    "]"}]}], "]"}]}], 
                   RowBox[{"Min", "[", 
                    RowBox[{
                    RowBox[{"2", "n"}], ",", 
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l", "-", "l1"}], ")"}], "/", "2"}], "+", "n", 
                    "-", "n1"}], "]"}]}], "]"}]], 
                  RowBox[{
                   UnderoverscriptBox["\[Sum]", 
                    RowBox[{"m1", "=", 
                    RowBox[{"Max", "[", 
                    RowBox[{
                    RowBox[{"-", "l1"}], ",", 
                    RowBox[{"l1", "-", 
                    RowBox[{"2", 
                    RowBox[{"(", 
                    RowBox[{"n", "-", "n1", "-", "n2"}], ")"}]}]}]}], "]"}]}], 
                    RowBox[{"Min", "[", 
                    RowBox[{"l1", ",", 
                    RowBox[{
                    RowBox[{"2", "l"}], "-", "l1", "+", 
                    RowBox[{"2", 
                    RowBox[{"(", 
                    RowBox[{"n", "-", "n1", "-", "n2"}], ")"}]}]}]}], "]"}]], 
                   
                   RowBox[{"With", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"l2", "=", 
                    RowBox[{
                    RowBox[{"2", 
                    RowBox[{"(", 
                    RowBox[{"n", "-", "n1", "-", "n2"}], ")"}]}], "+", "l", 
                    "-", "l1"}]}], ",", 
                    RowBox[{"n2p", "=", 
                    RowBox[{"n2", "+", "np", "-", "n"}]}]}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"KroneckerDelta", "[", 
                    RowBox[{"l2", ",", "0"}], "]"}], "-", "1"}], "2"], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], 
                    RowBox[{"l", "-", "l1"}]]}], ")"}], 
                    RowBox[{"GetA", "[", 
                    RowBox[{
                    "l", ",", "n", ",", "l1", ",", "m1", ",", "n1", ",", 
                    "n2"}], "]"}], 
                    RowBox[{"GetA", "[", 
                    RowBox[{
                    "l", ",", "np", ",", "l1", ",", "m1", ",", "n1", ",", 
                    "n2p"}], "]"}], 
                    RowBox[{"LagInt", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"l2", "+", "1"}], ",", 
                    RowBox[{"n2", "+", "1"}], ",", 
                    RowBox[{"n2p", "+", "1"}]}], 
                    "\[RightDoubleBracket]"}]}]}], "]"}]}]}]}]}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"a", "\[LeftDoubleBracket]", 
               RowBox[{
                RowBox[{"l", "+", "1"}], ",", 
                RowBox[{"np", "+", "1"}], ",", 
                RowBox[{"n", "+", "1"}]}], "\[RightDoubleBracket]"}], "=", 
              RowBox[{"a", "\[LeftDoubleBracket]", 
               RowBox[{
                RowBox[{"l", "+", "1"}], ",", 
                RowBox[{"n", "+", "1"}], ",", 
                RowBox[{"np", "+", "1"}]}], "\[RightDoubleBracket]"}]}]}]}], 
           "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
       "\[IndentingNewLine]", "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Chi]", "[", 
        RowBox[{"y_", "?", "NumericQ"}], "]"}], ":=", 
       RowBox[{"\[Pi]", "-", 
        RowBox[{"2", 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{"2", 
            RowBox[{"(", 
             RowBox[{"1", "-", "z"}], ")"}], 
            SqrtBox[
             FractionBox[
              RowBox[{"1", "-", "y"}], 
              RowBox[{"1", "-", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "-", "z"}], ")"}], "2"]}], ")"}], "2"], 
                RowBox[{"(", 
                 RowBox[{"1", "-", "y"}], ")"}]}], "-", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "-", "z"}], ")"}], "2"]}], ")"}], 
                 RowBox[{"\[Eta]", "-", "1"}]], "y"}]}]]]}], ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", "0", ",", "1"}], "}"}], ",", 
           RowBox[{"WorkingPrecision", "\[Rule]", "40"}], ",", 
           RowBox[{"MaxRecursion", "\[Rule]", "20"}]}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Il", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"LegendreP", "[", 
               RowBox[{"l", ",", 
                RowBox[{"Cos", "[", 
                 RowBox[{"\[Chi]", "[", "y", "]"}], "]"}]}], "]"}], "-", 
              "1"}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"\[Eta]", "-", "3"}], ")"}], "y"}], "+", "2"}], ")"}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"\[Eta]", "-", "1"}], ")"}], "y"}], ")"}], 
             FractionBox[
              RowBox[{"1", "+", "\[Eta]"}], 
              RowBox[{"1", "-", "\[Eta]"}]]]}], ",", 
           RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
           RowBox[{"WorkingPrecision", "\[Rule]", "40"}], ",", 
           RowBox[{"MaxRecursion", "\[Rule]", "20"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"l", ",", "0", ",", "Deg"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"LagInt", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{"n2", "+", "n2p"}]], 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"n2", "!"}], 
             RowBox[{"n2p", "!"}]}], 
            RowBox[{
             RowBox[{"Gamma", "[", 
              RowBox[{"n2", "+", "l2", "+", 
               RowBox[{"3", "/", "2"}]}], "]"}], 
             RowBox[{"Gamma", "[", 
              RowBox[{"n2p", "+", "l2", "+", 
               RowBox[{"3", "/", "2"}]}], "]"}]}]]], 
          RowBox[{"Gamma", "[", 
           RowBox[{"l2", "+", "1", "+", 
            FractionBox[
             RowBox[{"\[Eta]", "-", "3"}], 
             RowBox[{"\[Eta]", "-", "1"}]]}], "]"}], 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "0"}], 
            RowBox[{"Min", "[", 
             RowBox[{"n2", ",", "n2p"}], "]"}]], 
           RowBox[{
            RowBox[{"Binomial", "[", 
             RowBox[{
              RowBox[{
               FractionBox[
                RowBox[{"\[Eta]", "-", "3"}], 
                RowBox[{"\[Eta]", "-", "1"}]], "-", 
               FractionBox["1", "2"]}], ",", 
              RowBox[{"n2", "-", "k"}]}], "]"}], 
            RowBox[{"Binomial", "[", 
             RowBox[{
              RowBox[{
               FractionBox[
                RowBox[{"\[Eta]", "-", "3"}], 
                RowBox[{"\[Eta]", "-", "1"}]], "-", 
               FractionBox["1", "2"]}], ",", 
              RowBox[{"n2p", "-", "k"}]}], "]"}], 
            RowBox[{"Binomial", "[", 
             RowBox[{
              RowBox[{"k", "+", "l2", "+", 
               FractionBox[
                RowBox[{"\[Eta]", "-", "3"}], 
                RowBox[{"\[Eta]", "-", "1"}]]}], ",", "k"}], "]"}]}]}]}], ",",
          "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"l2", ",", "0", ",", "Deg"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n2", ",", "0", ",", 
           RowBox[{"Floor", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"Deg", "-", "l2"}], ")"}], "/", "2"}], "]"}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"n2p", ",", "0", ",", 
           RowBox[{"Floor", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"Deg", "-", "l2"}], ")"}], "/", "2"}], "]"}]}], "}"}]}],
         "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"a", "=", 
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"l", ",", "0", ",", "Deg"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", 
           RowBox[{"Floor", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"Deg", "-", "l"}], ")"}], "/", "2"}], "]"}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"np", ",", "0", ",", 
           RowBox[{"Floor", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"Deg", "-", "l"}], ")"}], "/", "2"}], "]"}]}], "}"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"l", "=", "0"}], ",", 
        RowBox[{"l", "\[LessEqual]", "Deg"}], ",", 
        RowBox[{"l", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"n", "=", "0"}], ",", 
          RowBox[{"n", "\[LessEqual]", 
           RowBox[{"Floor", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"Deg", "-", "l"}], ")"}], "/", "2"}], "]"}]}], ",", 
          RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"np", "=", "n"}], ",", 
            RowBox[{"np", "\[LessEqual]", 
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"Deg", "-", "l"}], ")"}], "/", "2"}], "]"}]}], ",", 
            RowBox[{"np", "++"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"a", "\[LeftDoubleBracket]", 
               RowBox[{
                RowBox[{"l", "+", "1"}], ",", 
                RowBox[{"n", "+", "1"}], ",", 
                RowBox[{"np", "+", "1"}]}], "\[RightDoubleBracket]"}], "=", 
              RowBox[{"4", "\[Pi]", 
               RowBox[{
                UnderoverscriptBox["\[Sum]", 
                 RowBox[{"l1", "=", "0"}], 
                 RowBox[{"l", "+", "n"}]], 
                RowBox[{
                 UnderoverscriptBox["\[Sum]", 
                  RowBox[{"n1", "=", "0"}], 
                  RowBox[{"Min", "[", 
                   RowBox[{
                    RowBox[{"2", "n"}], ",", 
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l", "-", "l1"}], ")"}], "/", "2"}], "+", "n"}], 
                    "]"}]}], "]"}]], 
                 RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                   RowBox[{"n2", "=", "0"}], 
                   RowBox[{"Min", "[", 
                    RowBox[{
                    RowBox[{"2", "n"}], ",", 
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l", "-", "l1"}], ")"}], "/", "2"}], "+", "n", 
                    "-", "n1"}], "]"}]}], "]"}]], 
                  RowBox[{
                   UnderoverscriptBox["\[Sum]", 
                    RowBox[{"m1", "=", 
                    RowBox[{"Max", "[", 
                    RowBox[{
                    RowBox[{"-", "l1"}], ",", 
                    RowBox[{"l1", "-", 
                    RowBox[{"2", 
                    RowBox[{"(", 
                    RowBox[{"n", "-", "n1", "-", "n2"}], ")"}]}]}]}], "]"}]}], 
                    RowBox[{"Min", "[", 
                    RowBox[{"l1", ",", 
                    RowBox[{
                    RowBox[{"2", "l"}], "-", "l1", "+", 
                    RowBox[{"2", 
                    RowBox[{"(", 
                    RowBox[{"n", "-", "n1", "-", "n2"}], ")"}]}]}]}], "]"}]], 
                   
                   RowBox[{"With", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"l2", "=", 
                    RowBox[{
                    RowBox[{"2", 
                    RowBox[{"(", 
                    RowBox[{"n", "-", "n1", "-", "n2"}], ")"}]}], "+", "l", 
                    "-", "l1"}]}], ",", 
                    RowBox[{"n2p", "=", 
                    RowBox[{"n2", "+", "np", "-", "n"}]}]}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    SuperscriptBox["2", 
                    FractionBox[
                    RowBox[{"1", "+", "\[Eta]"}], 
                    RowBox[{"1", "-", "\[Eta]"}]]], 
                    RowBox[{"Il", "\[LeftDoubleBracket]", 
                    RowBox[{"l2", "+", "1"}], "\[RightDoubleBracket]"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], 
                    RowBox[{"l", "-", "l1"}]]}], ")"}], 
                    RowBox[{"GetA", "[", 
                    RowBox[{
                    "l", ",", "n", ",", "l1", ",", "m1", ",", "n1", ",", 
                    "n2"}], "]"}], 
                    RowBox[{"GetA", "[", 
                    RowBox[{
                    "l", ",", "np", ",", "l1", ",", "m1", ",", "n1", ",", 
                    "n2p"}], "]"}], 
                    RowBox[{"LagInt", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"l2", "+", "1"}], ",", 
                    RowBox[{"n2", "+", "1"}], ",", 
                    RowBox[{"n2p", "+", "1"}]}], 
                    "\[RightDoubleBracket]"}]}]}], "]"}]}]}]}]}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"a", "\[LeftDoubleBracket]", 
               RowBox[{
                RowBox[{"l", "+", "1"}], ",", 
                RowBox[{"np", "+", "1"}], ",", 
                RowBox[{"n", "+", "1"}]}], "\[RightDoubleBracket]"}], "=", 
              RowBox[{"a", "\[LeftDoubleBracket]", 
               RowBox[{
                RowBox[{"l", "+", "1"}], ",", 
                RowBox[{"n", "+", "1"}], ",", 
                RowBox[{"np", "+", "1"}]}], "\[RightDoubleBracket]"}]}]}]}], 
           "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
       "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.625430946495652*^9, 3.6254310097135353`*^9}, {
  3.625431064168932*^9, 3.6254311602346*^9}, {3.6527021917925377`*^9, 
  3.652702192060382*^9}, {3.652702504010776*^9, 3.652702511175942*^9}, {
  3.652717327084256*^9, 3.6527173280373907`*^9}, {3.6534940477474737`*^9, 
  3.653494055513259*^9}, {3.782468704784602*^9, 3.782468705114006*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"dad0f3af-a9a7-4717-af20-3352aa5f4f35"]
}, Open  ]],

Cell[CellGroupData[{

Cell["General all coefficients", "Subsection",
 CellChangeTimes->{{3.782419520939568*^9, 3.7824195640431223`*^9}, {
  3.782419615996628*^9, 3.782419630620789*^9}, {3.78398314084492*^9, 
  3.783983146242516*^9}},ExpressionUUID->"0fbd4a14-e937-4df9-b821-\
a2071547fcdd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Coefficients", " ", 
    SubscriptBox["a", 
     RowBox[{"l", ",", "n", ",", 
      RowBox[{"n", "'"}]}]]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "A", " ", "warning", " ", "may", " ", "appear", " ", "at", " ", "this", 
     " ", "step"}], ",", " ", 
    RowBox[{
    "which", " ", "is", " ", "due", " ", "to", " ", "the", " ", "integral", 
     " ", "of", " ", "a", " ", "zero", " ", 
     RowBox[{"function", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"GenerateMatrix", "[", "\[Eta]", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a", "/=", 
     RowBox[{"Abs", "[", 
      RowBox[{"a", "\[LeftDoubleBracket]", 
       RowBox[{"3", ",", "1", ",", "1"}], "\[RightDoubleBracket]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Equation", " ", 
     RowBox[{"(", "3.21", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"n0", "[", "l_", "]"}], ":=", 
     RowBox[{"Switch", "[", 
      RowBox[{
      "l", ",", "0", ",", "2", ",", "1", ",", "2", ",", "2", ",", "1", ",", 
       "_", ",", "0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Coefficients", " ", 
     SubscriptBox["A", 
      RowBox[{"1", ",", "n"}]], " ", "and", " ", 
     SubscriptBox["A", 
      RowBox[{"2", ",", "n"}]], " ", "defined", " ", "in", " ", "equation", 
     " ", 
     RowBox[{"(", "3.15", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CoefA", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Inverse", "[", 
         RowBox[{"a", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", 
           RowBox[{"2", ";;"}], ",", 
           RowBox[{"2", ";;"}]}], "\[RightDoubleBracket]"}], "]"}], 
        "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
       RowBox[{
        RowBox[{"Inverse", "[", 
         RowBox[{"a", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
         "]"}], "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GetA", "[", 
      RowBox[{"l_", ",", "n_"}], "]"}], ":=", 
     RowBox[{"CoefA", "\[LeftDoubleBracket]", 
      RowBox[{"l", ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"l", "\[Equal]", "1"}], ",", "n", ",", 
         RowBox[{"n", "+", "1"}]}], "]"}]}], "\[RightDoubleBracket]"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Coefficients", " ", 
     SubscriptBox["B", 
      RowBox[{"l", ",", "n", ",", 
       RowBox[{"n", "'"}]}]], " ", "defined", " ", "in", " ", "equation", " ", 
     RowBox[{"(", "3.22", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CoefB", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"Length", "[", "a", "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"l", "=", "0"}], ",", 
      RowBox[{"l", "\[LessEqual]", "Deg"}], ",", 
      RowBox[{"++", "l"}], ",", 
      RowBox[{
       RowBox[{"CoefB", "\[LeftDoubleBracket]", 
        RowBox[{"l", "+", "1"}], "\[RightDoubleBracket]"}], "=", 
       RowBox[{"Inverse", "[", 
        RowBox[{"a", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"l", "+", "1"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"n0", "[", "l", "]"}], "+", "1"}], ";;"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"n0", "[", "l", "]"}], "+", "1"}], ";;"}]}], 
         "\[RightDoubleBracket]"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GetB", "[", 
      RowBox[{"l_", ",", "n_", ",", "n1_"}], "]"}], ":=", 
     RowBox[{"CoefB", "\[LeftDoubleBracket]", 
      RowBox[{
       RowBox[{"l", "+", "1"}], ",", 
       RowBox[{"n", "-", 
        RowBox[{"n0", "[", "l", "]"}], "+", "1"}], ",", 
       RowBox[{"n1", "-", 
        RowBox[{"n0", "[", "l", "]"}], "+", "1"}]}], 
      "\[RightDoubleBracket]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Coefficients", " ", 
     SubscriptBox["C", 
      RowBox[{"l", ",", "n"}]], " ", "defined", " ", "in", " ", "equation", 
     " ", 
     RowBox[{"(", "3.26", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CoefC", "=", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CoefC", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"-", "1"}], "}"}], "~", "Join", "~", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "CoefB", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ".", 
        
        RowBox[{"a", "\[LeftDoubleBracket]", 
         RowBox[{"2", ",", "2", ",", 
          RowBox[{"3", ";;"}]}], "\[RightDoubleBracket]"}]}], ")"}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CoefC", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
     "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"-", "1"}], "}"}], "~", "Join", "~", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "CoefB", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], ".", 
        
        RowBox[{"a", "\[LeftDoubleBracket]", 
         RowBox[{"3", ",", "1", ",", 
          RowBox[{"2", ";;"}]}], "\[RightDoubleBracket]"}]}], ")"}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GetC", "[", 
      RowBox[{"l_", ",", "n_"}], "]"}], ":=", 
     RowBox[{"CoefC", "\[LeftDoubleBracket]", 
      RowBox[{"l", ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"l", "\[Equal]", "1"}], ",", "n", ",", 
         RowBox[{"n", "+", "1"}]}], "]"}]}], "\[RightDoubleBracket]"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Coefficients", " ", 
     SubscriptBox["\[Lambda]", 
      RowBox[{"l", ",", "n"}]], " ", "defined", " ", "in", " ", "equation", 
     " ", 
     RowBox[{"(", "3.26", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Coef\[Lambda]", "=", 
     RowBox[{"CoefA", " ", "CoefC"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Coef\[Lambda]", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     "/=", 
     RowBox[{"GetA", "[", 
      RowBox[{"1", ",", "1"}], "]"}]}], ";", 
    RowBox[{
     RowBox[{
     "Coef\[Lambda]", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
     "/=", 
     RowBox[{"GetA", "[", 
      RowBox[{"2", ",", "0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Get\[Lambda]", "[", 
      RowBox[{"l_", ",", "n_"}], "]"}], ":=", 
     RowBox[{"Coef\[Lambda]", "\[LeftDoubleBracket]", 
      RowBox[{"l", ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"l", "\[Equal]", "1"}], ",", "n", ",", 
         RowBox[{"n", "+", "1"}]}], "]"}]}], "\[RightDoubleBracket]"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Coefficients", " ", 
     SubscriptBox["D", 
      RowBox[{"l", ",", "n"}]], " ", "defined", " ", "in", " ", "equation", 
     " ", 
     RowBox[{"(", "3.33", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CoefD", "=", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CoefD", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Total", "[", 
          RowBox[{"Coef\[Lambda]", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", 
            RowBox[{"2", ";;"}]}], "\[RightDoubleBracket]"}], "]"}]}], ")"}], 
       
       RowBox[{"-", "1"}]], 
      FractionBox["1", 
       RowBox[{"GetA", "[", 
        RowBox[{"1", ",", "1"}], "]"}]], 
      RowBox[{
       RowBox[{
       "CoefB", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ".", 
       RowBox[{"CoefA", "\[LeftDoubleBracket]", 
        RowBox[{"1", ",", 
         RowBox[{"2", ";;"}]}], "\[RightDoubleBracket]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CoefD", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
     "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Total", "[", 
          RowBox[{"Coef\[Lambda]", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", 
            RowBox[{"2", ";;"}]}], "\[RightDoubleBracket]"}], "]"}]}], ")"}], 
       
       RowBox[{"-", "1"}]], 
      FractionBox["1", 
       RowBox[{"GetA", "[", 
        RowBox[{"2", ",", "0"}], "]"}]], 
      RowBox[{
       RowBox[{
       "CoefB", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], ".", 
       RowBox[{"CoefA", "\[LeftDoubleBracket]", 
        RowBox[{"2", ",", 
         RowBox[{"2", ";;"}]}], "\[RightDoubleBracket]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GetD", "[", 
      RowBox[{"l_", ",", "n_"}], "]"}], ":=", 
     RowBox[{"CoefD", "\[LeftDoubleBracket]", 
      RowBox[{"l", ",", 
       RowBox[{"n", "-", 
        RowBox[{"n0", "[", "l", "]"}], "+", "1"}]}], 
      "\[RightDoubleBracket]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7824201987937117`*^9, 3.782420346757725*^9}, {
   3.782420553464963*^9, 3.782420562562004*^9}, {3.782420607103694*^9, 
   3.782420771997538*^9}, {3.7824210007456217`*^9, 3.782421050230962*^9}, {
   3.78242113489377*^9, 3.78242114083037*^9}, {3.782448185733095*^9, 
   3.782448302427862*^9}, {3.78244833398941*^9, 3.782448362340431*^9}, {
   3.78246646193402*^9, 3.782466498363536*^9}, {3.782466559733837*^9, 
   3.782466658284584*^9}, {3.78246675665991*^9, 3.782466765322174*^9}, {
   3.7824689455252666`*^9, 3.782468948238385*^9}, {3.7824726529317083`*^9, 
   3.782472675381081*^9}, {3.782512592706068*^9, 3.782512606497446*^9}, {
   3.782512639222039*^9, 3.782512658232027*^9}, {3.782512688786783*^9, 
   3.782512853805257*^9}, 3.782512974626794*^9, {3.7825587544148407`*^9, 
   3.782558764938181*^9}, {3.782599855472801*^9, 3.782599871164019*^9}, {
   3.783983212189259*^9, 3.783983225578405*^9}, {3.783983265340383*^9, 
   3.783983361425686*^9}, {3.7839834011661253`*^9, 3.783983415968443*^9}, {
   3.783983469236532*^9, 3.783983476771686*^9}, {3.783983585436925*^9, 
   3.783983588282571*^9}, {3.784115529343273*^9, 3.784115530566848*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"fcd8fb56-2fed-472e-bff5-0587af1e0046"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["First order (Section 3.2.1)", "Section",
 CellChangeTimes->{{3.782421209514614*^9, 3.782421217816535*^9}, {
  3.782421273208267*^9, 3.782421279465407*^9}, {3.7839829175254908`*^9, 
  3.783982920209138*^9}},ExpressionUUID->"75fd2d51-0253-4600-b328-\
5ba9b0de2b18"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f1", "=", 
    RowBox[{"Table", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"l", ",", "0", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "l"}], ",", "l"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "0", ",", 
        RowBox[{"Floor", "[", 
         FractionBox[
          RowBox[{"Deg", "-", "l"}], "2"], "]"}]}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Equation", " ", 
    RowBox[{"(", "3.16", ")"}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"m", "=", 
     RowBox[{"-", "1"}]}], ",", 
    RowBox[{"m", "\[LessEqual]", "1"}], ",", 
    RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"n", "=", "1"}], ",", 
      RowBox[{"n", "\[LessEqual]", 
       RowBox[{"Floor", "[", 
        FractionBox[
         RowBox[{"Deg", "-", "1"}], "2"], "]"}]}], ",", 
      RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"f1", "\[LeftDoubleBracket]", 
         RowBox[{"Idx", "[", 
          RowBox[{"1", ",", "m", ",", "n"}], "]"}], "\[RightDoubleBracket]"}],
         "=", 
        RowBox[{
         RowBox[{
          RowBox[{"GetA", "[", 
           RowBox[{"1", ",", "n"}], "]"}], "/", 
          RowBox[{"GetA", "[", 
           RowBox[{"1", ",", "1"}], "]"}]}], 
         RowBox[{"F", "[", 
          RowBox[{"1", ",", "m", ",", "1"}], "]"}], 
         SuperscriptBox["\[CapitalTheta]", 
          RowBox[{"n", "-", "1"}]]}]}], ";"}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"m", "=", 
     RowBox[{"-", "2"}]}], ",", 
    RowBox[{"m", "\[LessEqual]", "2"}], ",", 
    RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"n", "=", "0"}], ",", 
      RowBox[{"n", "\[LessEqual]", 
       RowBox[{"Floor", "[", 
        FractionBox[
         RowBox[{"Deg", "-", "2"}], "2"], "]"}]}], ",", 
      RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"f1", "\[LeftDoubleBracket]", 
         RowBox[{"Idx", "[", 
          RowBox[{"2", ",", "m", ",", "n"}], "]"}], "\[RightDoubleBracket]"}],
         "=", 
        RowBox[{
         RowBox[{
          RowBox[{"GetA", "[", 
           RowBox[{"2", ",", "n"}], "]"}], "/", 
          RowBox[{"GetA", "[", 
           RowBox[{"2", ",", "0"}], "]"}]}], 
         RowBox[{"F", "[", 
          RowBox[{"2", ",", "m", ",", "0"}], "]"}], 
         SuperscriptBox["\[CapitalTheta]", "n"]}]}], ";"}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.782421287336979*^9, 3.782421300638769*^9}, {
   3.782430057170945*^9, 3.782430095700645*^9}, {3.782430163178094*^9, 
   3.7824304525968943`*^9}, {3.7824304886019707`*^9, 3.782430490921891*^9}, 
   3.782430608021351*^9, {3.782443051110342*^9, 3.782443054937879*^9}, {
   3.782443774164125*^9, 3.782443774284539*^9}, {3.782443849395692*^9, 
   3.782443849661704*^9}, {3.782466799740797*^9, 3.782466861832033*^9}, {
   3.7824697846636887`*^9, 3.782469789616559*^9}, {3.782470284023017*^9, 
   3.7824702857053957`*^9}, {3.783982951795993*^9, 3.783982960699744*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"ab8e8502-79ac-4527-9adc-62d06e53750a"],

Cell[CellGroupData[{

Cell["Create functions", "Subsection",
 CellChangeTimes->{{3.7839839426316547`*^9, 
  3.783983944765965*^9}},ExpressionUUID->"79d2130d-cac2-4c78-a525-\
c9e093f61848"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f1func", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"exprToFunction", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "}"}]}], "]"}], "&"}], ",", 
     "f1", ",", 
     RowBox[{"{", "3", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.782443554914007*^9, 3.782443560680851*^9}, {
  3.782443653071949*^9, 3.78244373907726*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"c0c12798-ddc0-40ad-a563-27c006022168"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Second order (Section 3.2.2)", "Section",
 CellChangeTimes->{{3.782430611982136*^9, 3.7824306142156982`*^9}, {
  3.783982985231666*^9, 
  3.7839829870982656`*^9}},ExpressionUUID->"898aa40e-e33d-4352-8e10-\
34afb21d2190"],

Cell[CellGroupData[{

Cell["Asymptotic expansion", "Subsection",
 CellChangeTimes->{{3.782513434851177*^9, 
  3.782513438905581*^9}},ExpressionUUID->"eb29aa3a-c0ba-4cb1-90bc-\
bb3f217ddf79"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"l", ",", "0", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "l"}], ",", "l"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "0", ",", 
        RowBox[{
         RowBox[{"Floor", "[", 
          FractionBox[
           RowBox[{"Deg", "-", "l"}], "2"], "]"}], "-", "1"}]}], "}"}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Equation", " ", 
    RowBox[{"(", "3.21", ")"}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"l", "=", "0"}], ",", 
    RowBox[{"l", "\[LessEqual]", "4"}], ",", 
    RowBox[{"l", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"-", "l"}]}], ",", 
      RowBox[{"m", "\[LessEqual]", "l"}], ",", 
      RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"n", "=", 
         RowBox[{"n0", "[", "l", "]"}]}], ",", 
        RowBox[{"n", "<", 
         RowBox[{"Floor", "[", 
          FractionBox[
           RowBox[{"Deg", "-", "l"}], "2"], "]"}]}], ",", 
        RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"f2", "\[LeftDoubleBracket]", 
          RowBox[{"Idx", "[", 
           RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
          "\[RightDoubleBracket]"}], "+=", 
         RowBox[{
          FractionBox["\[Mu]", 
           RowBox[{
            RowBox[{"F", "[", 
             RowBox[{"0", ",", "0", ",", "0"}], "]"}], "\[CapitalTheta]"}]], 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"n1", "=", 
             RowBox[{"n0", "[", "l", "]"}]}], 
            RowBox[{
             RowBox[{"n0", "[", "l", "]"}], "+", 
             RowBox[{"Length", "[", 
              RowBox[{"CoefB", "\[LeftDoubleBracket]", 
               RowBox[{"l", "+", "1"}], "\[RightDoubleBracket]"}], "]"}], "-",
              "3"}]], 
           RowBox[{
            RowBox[{"GetB", "[", 
             RowBox[{"l", ",", "n", ",", "n1"}], "]"}], 
            SuperscriptBox["\[CapitalTheta]", 
             RowBox[{"n", "-", "n1"}]], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["\[PartialD]", "t"], 
               RowBox[{"f1", "\[LeftDoubleBracket]", 
                RowBox[{"Idx", "[", 
                 RowBox[{"l", ",", "m", ",", "n1"}], "]"}], 
                "\[RightDoubleBracket]"}]}], "+", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"S", "[", 
                  RowBox[{"l", ",", "m", ",", "n1"}], "]"}], "+", 
                 RowBox[{"T", "[", 
                  RowBox[{"l", ",", "m", ",", "n1"}], "]"}]}], "/.", 
                RowBox[{
                 SubscriptBox["f", 
                  RowBox[{"l_", ",", "m_", ",", "n_"}]], "\[RuleDelayed]", 
                 RowBox[{"f1func", "\[LeftDoubleBracket]", 
                  RowBox[{"Idx", "[", 
                   RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
                  "\[RightDoubleBracket]"}]}]}], ")"}]}], ")"}]}]}]}]}]}], 
       "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.782430615707686*^9, 3.782430622058848*^9}, 
   3.782443838064443*^9, {3.7824438769414797`*^9, 3.7824439165824842`*^9}, {
   3.7824439559936533`*^9, 3.782444033152246*^9}, {3.782444066750444*^9, 
   3.782444262499892*^9}, {3.782447535803316*^9, 3.782447535996462*^9}, {
   3.7824478016245604`*^9, 3.782447804017685*^9}, {3.782448082764413*^9, 
   3.782448103515915*^9}, {3.782448135948875*^9, 3.782448160153405*^9}, {
   3.782448602818063*^9, 3.7824486162411613`*^9}, {3.782448754703718*^9, 
   3.7824487869982653`*^9}, {3.782448825266815*^9, 3.782448825322076*^9}, {
   3.782448964990102*^9, 3.78244898855665*^9}, {3.782449071597546*^9, 
   3.782449077215354*^9}, {3.782449289610896*^9, 3.78244928971876*^9}, {
   3.7824493217566137`*^9, 3.78244932210058*^9}, {3.782450070498654*^9, 
   3.782450077168622*^9}, {3.782466901734314*^9, 3.782466905687207*^9}, {
   3.782468974824211*^9, 3.782468975231743*^9}, {3.7839830329693403`*^9, 
   3.783983038342166*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"c47755fa-7e3e-49db-945c-b9f708f7ae52"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Replace time derivatives of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", 
    RowBox[{"1", ",", "m", ",", "n"}]], TraditionalForm]],ExpressionUUID->
  "d4386aca-a7db-4a0f-aaf3-744338ce88ca"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", 
    RowBox[{"2", ",", "m", ",", "n"}]], TraditionalForm]],ExpressionUUID->
  "06d5fcd6-71d7-452b-ab6c-14c74f3ceeea"]
}], "Subsection",
 CellChangeTimes->{{3.782513503163629*^9, 
  3.782513531522138*^9}},ExpressionUUID->"99ae5e9d-0bad-45b5-8470-\
fc118b60a607"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Equation", " ", 
    RowBox[{"(", "3.25", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Dtf1m11", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"Total", "[", 
            RowBox[{"Coef\[Lambda]", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", 
              RowBox[{"2", ";;"}]}], "\[RightDoubleBracket]"}], "]"}]}], 
          ")"}], 
         RowBox[{"-", "1"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "Kn"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox[
               RowBox[{
                RowBox[{"F", "[", 
                 RowBox[{"0", ",", "0", ",", "0"}], "]"}], 
                "\[CapitalTheta]"}], "\[Mu]"], 
              FractionBox[
               RowBox[{"F", "[", 
                RowBox[{"1", ",", "m", ",", "1"}], "]"}], 
               RowBox[{"GetA", "[", 
                RowBox[{"1", ",", "1"}], "]"}]]}], "-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"T", "[", 
                RowBox[{"1", ",", "m", ",", "1"}], "]"}], "/.", 
               RowBox[{
                RowBox[{
                 SubscriptBox["f", 
                  RowBox[{"l0_", ",", "m0_", ",", "n0_"}]], "/;", 
                 RowBox[{
                  RowBox[{"l0", "\[NotEqual]", "0"}], "||", 
                  RowBox[{"m0", "\[NotEqual]", "0"}], "||", 
                  RowBox[{"n0", "\[NotEqual]", "0"}]}]}], "\[Rule]", 
                RowBox[{"(", 
                 RowBox[{"0", "&"}], ")"}]}]}], ")"}]}], ")"}]}], "+", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"n1", "=", "2"}], 
            RowBox[{"Floor", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Deg", "-", "1"}], ")"}], "/", "2"}], "]"}]], 
           RowBox[{
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n1", "-", "1"}], ")"}], 
              RowBox[{"Get\[Lambda]", "[", 
               RowBox[{"1", ",", "n1"}], "]"}]}], "\[CapitalTheta]"], 
            RowBox[{
             SubscriptBox["\[PartialD]", "t"], "\[CapitalTheta]"}], " ", 
            RowBox[{"F", "[", 
             RowBox[{"1", ",", "m", ",", "1"}], "]"}]}]}], "+", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"n1", "=", "1"}], 
            RowBox[{
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"Deg", "-", "1"}], ")"}], "/", "2"}], "]"}], "-", 
             "2"}]], 
           RowBox[{
            RowBox[{"GetC", "[", 
             RowBox[{"1", ",", "n1"}], "]"}], 
            SuperscriptBox["\[CapitalTheta]", 
             RowBox[{"1", "-", "n1"}]], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"S", "[", 
                RowBox[{"1", ",", "m", ",", "n1"}], "]"}], "+", 
               RowBox[{"T", "[", 
                RowBox[{"1", ",", "m", ",", "n1"}], "]"}]}], "/.", 
              RowBox[{
               SubscriptBox["f", 
                RowBox[{"l0_", ",", "m0_", ",", "n0_"}]], "\[RuleDelayed]", 
               RowBox[{"f1func", "\[LeftDoubleBracket]", 
                RowBox[{"Idx", "[", 
                 RowBox[{"l0", ",", "m0", ",", "n0"}], "]"}], 
                "\[RightDoubleBracket]"}]}]}], ")"}]}]}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Equation", " ", 
     RowBox[{"(", "3.27", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dtf2m01", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"Total", "[", 
            RowBox[{"Coef\[Lambda]", "\[LeftDoubleBracket]", 
             RowBox[{"2", ",", 
              RowBox[{"2", ";;"}]}], "\[RightDoubleBracket]"}], "]"}]}], 
          ")"}], 
         RowBox[{"-", "1"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "Kn"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox[
               RowBox[{
                RowBox[{"F", "[", 
                 RowBox[{"0", ",", "0", ",", "0"}], "]"}], 
                "\[CapitalTheta]"}], "\[Mu]"], 
              FractionBox[
               RowBox[{"F", "[", 
                RowBox[{"2", ",", "m", ",", "0"}], "]"}], 
               RowBox[{"GetA", "[", 
                RowBox[{"2", ",", "0"}], "]"}]]}], "-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"T", "[", 
                RowBox[{"2", ",", "m", ",", "0"}], "]"}], "/.", 
               RowBox[{
                RowBox[{
                 SubscriptBox["f", 
                  RowBox[{"l0_", ",", "m0_", ",", "n0_"}]], "/;", 
                 RowBox[{
                  RowBox[{"l0", "\[NotEqual]", "0"}], "||", 
                  RowBox[{"m0", "\[NotEqual]", "0"}], "||", 
                  RowBox[{"n0", "\[NotEqual]", "0"}]}]}], "\[Rule]", 
                RowBox[{"(", 
                 RowBox[{"0", "&"}], ")"}]}]}], ")"}]}], ")"}]}], "+", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"n1", "=", "1"}], 
            RowBox[{"Floor", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Deg", "-", "2"}], ")"}], "/", "2"}], "]"}]], 
           RowBox[{
            FractionBox[
             RowBox[{"n1", " ", 
              RowBox[{"Get\[Lambda]", "[", 
               RowBox[{"2", ",", "n1"}], "]"}]}], "\[CapitalTheta]"], 
            RowBox[{
             SubscriptBox["\[PartialD]", "t"], "\[CapitalTheta]"}], " ", 
            RowBox[{"F", "[", 
             RowBox[{"2", ",", "m", ",", "0"}], "]"}]}]}], "+", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"n1", "=", "0"}], 
            RowBox[{
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"Deg", "-", "1"}], ")"}], "/", "2"}], "]"}], "-", 
             "2"}]], 
           RowBox[{
            RowBox[{"GetC", "[", 
             RowBox[{"2", ",", "n1"}], "]"}], 
            SuperscriptBox["\[CapitalTheta]", 
             RowBox[{"-", "n1"}]], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"S", "[", 
                RowBox[{"2", ",", "m", ",", "n1"}], "]"}], "+", 
               RowBox[{"T", "[", 
                RowBox[{"2", ",", "m", ",", "n1"}], "]"}]}], "/.", 
              RowBox[{
               SubscriptBox["f", 
                RowBox[{"l0_", ",", "m0_", ",", "n0_"}]], "\[RuleDelayed]", 
               RowBox[{"f1func", "\[LeftDoubleBracket]", 
                RowBox[{"Idx", "[", 
                 RowBox[{"l0", ",", "m0", ",", "n0"}], "]"}], 
                "\[RightDoubleBracket]"}]}]}], ")"}]}]}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]}], ";"}]}]}]], "Input",\

 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQzbVkWXyx3hvHLu1jqSD62fxbeSD6znKJAhBdM9+z
FEQnchZXg+gZGqfaQbTZT6WpILou4c8MEM2VpLYczJ80fQ2Izvo+cS2I7hFW
2gaiHWqSwHTfDpXDIDr1EttxED3FJfIqiJ7KV3kNRBu0TL0Lor1ULoDptZvk
H4HoNZ+1noNo/fjJv8F85hPMJUD69j0hbhCt956fvwSsPlsKRF9V5FUE0SlN
7uurgbRJYcRuEF1vt4WvHkgzXtgPpq2Ka0VA9PYtPWB6n/oruxVAepa3iQOI
3pH11iHB8I3jz90zHUG0c99kTxCtF7zXC0QDAK/clnc=
  "],
 CellLabel->"In[45]:=",ExpressionUUID->"f4211b57-0e51-4ea1-8b29-9f7d6d323e3d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Make", " ", "replacement"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Rules", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"i_", ",", "j_", ",", "k_", ",", "1"}], "]"}], "[", 
          SubscriptBox["f", 
           RowBox[{"1", ",", "m_", ",", "1"}]], "]"}], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"Dtf1m11", "\[LeftDoubleBracket]", 
           RowBox[{"m", "+", "2"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "1"], ",", "i"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "2"], ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "3"], ",", "k"}], "}"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"i_", ",", "j_", ",", "k_", ",", "1"}], "]"}], "[", 
          SubscriptBox["f", 
           RowBox[{"2", ",", "m_", ",", "0"}]], "]"}], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"Dtf2m01", "\[LeftDoubleBracket]", 
           RowBox[{"m", "+", "3"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "1"], ",", "i"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "2"], ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "3"], ",", "k"}], "}"}]}], "]"}]}]}], "}"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"l", "=", "0"}], ",", 
      RowBox[{"l", "\[LessEqual]", "4"}], ",", 
      RowBox[{"l", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"m", "=", 
         RowBox[{"-", "l"}]}], ",", 
        RowBox[{"m", "\[LessEqual]", "l"}], ",", 
        RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"n", "=", 
           RowBox[{"n0", "[", "l", "]"}]}], ",", 
          RowBox[{"n", "<", 
           RowBox[{"Floor", "[", 
            FractionBox[
             RowBox[{"Deg", "-", "l"}], "2"], "]"}]}], ",", 
          RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"f2", "\[LeftDoubleBracket]", 
            RowBox[{"Idx", "[", 
             RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
            "\[RightDoubleBracket]"}], "=", 
           RowBox[{
            RowBox[{"f2", "\[LeftDoubleBracket]", 
             RowBox[{"Idx", "[", 
              RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
             "\[RightDoubleBracket]"}], "/.", "Rules"}]}]}], 
         "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.782451608568618*^9, 3.782451619307282*^9}, {
   3.7824516775776978`*^9, 3.7824516777762403`*^9}, {3.7824517559900723`*^9, 
   3.782451916612555*^9}, 3.782451973317288*^9, {3.782558212667961*^9, 
   3.782558217719359*^9}, {3.783983718608501*^9, 3.7839837236365747`*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"850e80a0-b70d-4bf5-a9ea-9e137b652f02"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Replace time derivatives of ",
 Cell[BoxData[
  FormBox["u", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "92f3a445-ef88-429d-ac12-0ceab1710d2f"],
 " and ",
 Cell[BoxData[
  FormBox["\[Theta]", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "2354b4fc-0d52-4ca2-bf7f-d1764611613f"]
}], "Subsection",
 CellChangeTimes->{{3.782513536960033*^9, 
  3.7825135587402487`*^9}},ExpressionUUID->"99190ba9-6f4d-4fc5-b177-\
e5d4264d4719"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Velocity", " ", "and", " ", "temperature", " ", "equations", " ", "in", 
    " ", "the", " ", "Euler", " ", "equations"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Euler", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          SubscriptBox["v", "1"], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], ",", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["v", "2"], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], ",", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["v", "3"], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], ",", 
        RowBox[{
         SuperscriptBox["\[Theta]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "}"}], "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"S", "[", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}], ",", "0"}], "]"}], "+", 
              RowBox[{"T", "[", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}], ",", "0"}], "]"}]}], "\[Equal]", "0"}], 
            ",", 
            RowBox[{
             RowBox[{
              RowBox[{"S", "[", 
               RowBox[{"1", ",", "0", ",", "0"}], "]"}], "+", 
              RowBox[{"T", "[", 
               RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "\[Equal]", "0"}], 
            ",", 
            RowBox[{
             RowBox[{
              RowBox[{"S", "[", 
               RowBox[{"1", ",", "1", ",", "0"}], "]"}], "+", 
              RowBox[{"T", "[", 
               RowBox[{"1", ",", "1", ",", "0"}], "]"}]}], "\[Equal]", "0"}], 
            ",", 
            RowBox[{
             RowBox[{
              RowBox[{"S", "[", 
               RowBox[{"0", ",", "0", ",", "1"}], "]"}], "+", 
              RowBox[{"T", "[", 
               RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "\[Equal]", 
             "0"}]}], "}"}], "/.", 
          RowBox[{
           RowBox[{
            SubscriptBox["f", 
             RowBox[{"l0_", ",", "m0_", ",", "n0_"}]], "/;", 
            RowBox[{
             RowBox[{"l0", "\[NotEqual]", "0"}], "||", 
             RowBox[{"m0", "\[NotEqual]", "0"}], "||", 
             RowBox[{"n0", "\[NotEqual]", "0"}]}]}], "\[Rule]", 
           RowBox[{"(", 
            RowBox[{"0", "&"}], ")"}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             SubscriptBox["v", "1"], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             SubscriptBox["x", "1"], ",", 
             SubscriptBox["x", "2"], ",", 
             SubscriptBox["x", "3"], ",", "t"}], "]"}], ",", 
           RowBox[{
            SuperscriptBox[
             SubscriptBox["v", "2"], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             SubscriptBox["x", "1"], ",", 
             SubscriptBox["x", "2"], ",", 
             SubscriptBox["x", "3"], ",", "t"}], "]"}], ",", 
           RowBox[{
            SuperscriptBox[
             SubscriptBox["v", "3"], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             SubscriptBox["x", "1"], ",", 
             SubscriptBox["x", "2"], ",", 
             SubscriptBox["x", "3"], ",", "t"}], "]"}], ",", 
           RowBox[{
            SuperscriptBox["\[Theta]", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             SubscriptBox["x", "1"], ",", 
             SubscriptBox["x", "2"], ",", 
             SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "}"}]}], "]"}], 
       "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Make", " ", "replacement"}], " ", "*)"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"RuleV\[CapitalTheta]", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"i_", ",", "j_", ",", "k_", ",", "1"}], "]"}], "[", 
          SubscriptBox["v", "1"], "]"}], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
          "Euler", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "1"], ",", "i"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "2"], ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "3"], ",", "k"}], "}"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"i_", ",", "j_", ",", "k_", ",", "1"}], "]"}], "[", 
          SubscriptBox["v", "2"], "]"}], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
          "Euler", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "1"], ",", "i"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "2"], ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "3"], ",", "k"}], "}"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"i_", ",", "j_", ",", "k_", ",", "1"}], "]"}], "[", 
          SubscriptBox["v", "3"], "]"}], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
          "Euler", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "1"], ",", "i"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "2"], ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "3"], ",", "k"}], "}"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"i_", ",", "j_", ",", "k_", ",", "1"}], "]"}], "[", 
          "\[Theta]", "]"}], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
          "Euler", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "1"], ",", "i"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "2"], ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "3"], ",", "k"}], "}"}]}], "]"}]}]}], "}"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"l", "=", "0"}], ",", 
      RowBox[{"l", "\[LessEqual]", "4"}], ",", 
      RowBox[{"l", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"m", "=", 
         RowBox[{"-", "l"}]}], ",", 
        RowBox[{"m", "\[LessEqual]", "l"}], ",", 
        RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"n", "=", 
           RowBox[{"n0", "[", "l", "]"}]}], ",", 
          RowBox[{"n", "<", 
           RowBox[{"Floor", "[", 
            FractionBox[
             RowBox[{"Deg", "-", "l"}], "2"], "]"}]}], ",", 
          RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"f2", "\[LeftDoubleBracket]", 
            RowBox[{"Idx", "[", 
             RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
            "\[RightDoubleBracket]"}], "=", 
           RowBox[{"Chop", "[", 
            RowBox[{"Expand", "[", 
             RowBox[{
              RowBox[{"f2", "\[LeftDoubleBracket]", 
               RowBox[{"Idx", "[", 
                RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
               "\[RightDoubleBracket]"}], "/.", "RuleV\[CapitalTheta]"}], 
             "]"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
       "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7825141900691843`*^9, 3.782514330690835*^9}, {
  3.78251438843504*^9, 3.782514393770638*^9}, {3.782599978684823*^9, 
  3.7825999820282497`*^9}, {3.782604177322096*^9, 3.782604181782695*^9}, {
  3.783983749086686*^9, 3.783983828717473*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"8306fb79-78de-4217-bbe7-4b24d33cc76e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Split the result to ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["W", 
    RowBox[{"l", ",", "m", ",", "n"}], 
    RowBox[{"(", "1", ")"}]], TraditionalForm]],ExpressionUUID->
  "6b562004-5a65-4950-9115-f2be1ac172af"],
 " (terms with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", "\[Epsilon]"}], TraditionalForm]],ExpressionUUID->
  "4138bc2a-798a-4b1b-906e-b4997779c800"],
 ") and ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["W", 
    RowBox[{"l", ",", "m", ",", "n"}], 
    RowBox[{"(", "2", ")"}]], TraditionalForm]],ExpressionUUID->
  "18e40701-070f-4c94-8d84-bf86bfdd9b49"],
 " (terms with no ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", "\[Epsilon]"}], TraditionalForm]],ExpressionUUID->
  "9823b30b-c8b4-4e80-a0e6-0294e199e5e8"],
 ")"
}], "Subsection",
 CellChangeTimes->{{3.782513569543831*^9, 
  3.782513677185882*^9}},ExpressionUUID->"b62671fd-0a73-4fe3-a933-\
73a48e4cc93a"],

Cell[TextData[{
 "Here W2 corresponds to ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["W", 
    RowBox[{"l", ",", "m", ",", "n"}], 
    RowBox[{"(", "2", ")"}]], TraditionalForm]],ExpressionUUID->
  "a9413b67-03d1-4dd7-899b-37b8cb05fcfd"],
 " given in (3.29) and (3.30)."
}], "Text",
 CellChangeTimes->{{3.783983847242197*^9, 3.783983860027321*^9}, {
   3.783983894322681*^9, 3.783983922746553*^9}, {3.7841157396437397`*^9, 
   3.7841157454616737`*^9}, 
   3.784117337465561*^9},ExpressionUUID->"88d56226-de62-4641-9e4a-\
4e5dfc53e587"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"W2", "=", "f2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"W1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"-", "l"}], ",", "l"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", 
       RowBox[{
        RowBox[{"Floor", "[", 
         FractionBox[
          RowBox[{"Deg", "-", "l"}], "2"], "]"}], "-", "1"}]}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"l", "=", "1"}], ",", 
   RowBox[{"l", "\[LessEqual]", "2"}], ",", 
   RowBox[{"l", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"m", "=", 
      RowBox[{"-", "l"}]}], ",", 
     RowBox[{"m", "\[LessEqual]", "l"}], ",", 
     RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"n", "=", 
        RowBox[{"n0", "[", "l", "]"}]}], ",", 
       RowBox[{"n", "<", 
        RowBox[{"Length", "[", 
         RowBox[{"f2", "\[LeftDoubleBracket]", 
          RowBox[{
           RowBox[{"l", "+", "1"}], ",", "1"}], "\[RightDoubleBracket]"}], 
         "]"}]}], ",", 
       RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"W2", "\[LeftDoubleBracket]", 
          RowBox[{"Idx", "[", 
           RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
          "\[RightDoubleBracket]"}], "=", 
         RowBox[{
          RowBox[{"f2", "\[LeftDoubleBracket]", 
           RowBox[{"Idx", "[", 
            RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
           "\[RightDoubleBracket]"}], "/.", 
          RowBox[{"Kn", "\[Rule]", 
           RowBox[{"+", "\[Infinity]"}]}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"W1", "\[LeftDoubleBracket]", 
          RowBox[{"Idx", "[", 
           RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
          "\[RightDoubleBracket]"}], "=", 
         RowBox[{"Chop", "[", 
          RowBox[{"Simplify", "[", 
           RowBox[{
            RowBox[{"f2", "\[LeftDoubleBracket]", 
             RowBox[{"Idx", "[", 
              RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
             "\[RightDoubleBracket]"}], "-", 
            RowBox[{"W2", "\[LeftDoubleBracket]", 
             RowBox[{"Idx", "[", 
              RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
             "\[RightDoubleBracket]"}]}], "]"}], "]"}]}], ";"}]}], 
      "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]", "]"}]}], "Input",
 CellChangeTimes->{{3.782513685353883*^9, 3.78251375052772*^9}, {
  3.782513786610238*^9, 3.7825139536983624`*^9}, {3.782548411303241*^9, 
  3.782548451816926*^9}, {3.782600042951877*^9, 3.7826000705070868`*^9}, {
  3.782600109807197*^9, 3.7826001101821423`*^9}, {3.7826001758528023`*^9, 
  3.782600178563109*^9}, {3.78260023900318*^9, 3.782600242493889*^9}, {
  3.784115821086966*^9, 3.78411585442511*^9}, {3.784117463980959*^9, 
  3.7841174796370707`*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"6e6247ce-d184-4547-9cb7-7bd7f4e4e8f4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Create functions", "Subsection",
 CellChangeTimes->{{3.782526222043543*^9, 
  3.782526223933003*^9}},ExpressionUUID->"543d9f4f-8ac6-450c-8b3a-\
6d13b7334546"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f2func", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"exprToFunction", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "}"}]}], "]"}], "&"}], ",", 
     "f2", ",", 
     RowBox[{"{", "3", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.78252623959085*^9, 3.7825262421146097`*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"7b261c18-3cbf-4d97-b3de-402dc0d186cd"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Third order (Section 3.2.3)", "Section",
 CellChangeTimes->{{3.782514491207103*^9, 3.7825144940213013`*^9}, {
  3.78398408103609*^9, 
  3.783984093461934*^9}},ExpressionUUID->"9dcad94b-2e57-4e4a-a066-\
08af6a467087"],

Cell["\<\
Running this section may take several minutes due to the complicated \
expression of third-order terms.\
\>", "Text",
 CellChangeTimes->{{3.7841175029408207`*^9, 
  3.784117538760791*^9}},ExpressionUUID->"6ee8e014-e9f1-4272-ac0d-\
12447566ce20"],

Cell[CellGroupData[{

Cell["Conservation laws", "Subsection",
 CellChangeTimes->{{3.7825482047554007`*^9, 
  3.78254820631671*^9}},ExpressionUUID->"12f4994d-514f-4a20-ab7a-\
c69ba3404a69"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Equations", " ", 
    RowBox[{"(", "2.22", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Csv", "=", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            SubscriptBox["f", 
             RowBox[{"0", ",", "0", ",", "0"}]], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            SubscriptBox["x", "1"], ",", 
            SubscriptBox["x", "2"], ",", 
            SubscriptBox["x", "3"], ",", "t"}], "]"}], ",", 
          RowBox[{
           SuperscriptBox[
            SubscriptBox["v", "1"], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            SubscriptBox["x", "1"], ",", 
            SubscriptBox["x", "2"], ",", 
            SubscriptBox["x", "3"], ",", "t"}], "]"}], ",", 
          RowBox[{
           SuperscriptBox[
            SubscriptBox["v", "2"], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            SubscriptBox["x", "1"], ",", 
            SubscriptBox["x", "2"], ",", 
            SubscriptBox["x", "3"], ",", "t"}], "]"}], ",", 
          RowBox[{
           SuperscriptBox[
            SubscriptBox["v", "3"], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            SubscriptBox["x", "1"], ",", 
            SubscriptBox["x", "2"], ",", 
            SubscriptBox["x", "3"], ",", "t"}], "]"}], ",", 
          RowBox[{
           SuperscriptBox["\[Theta]", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            SubscriptBox["x", "1"], ",", 
            SubscriptBox["x", "2"], ",", 
            SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "}"}], "/.", 
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 SubscriptBox["f", 
                  RowBox[{"0", ",", "0", ",", "0"}]], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 SubscriptBox["x", "1"], ",", 
                 SubscriptBox["x", "2"], ",", 
                 SubscriptBox["x", "3"], ",", "t"}], "]"}], "+", 
               RowBox[{"S", "[", 
                RowBox[{"0", ",", "0", ",", "0"}], "]"}], "+", 
               RowBox[{"T", "[", 
                RowBox[{"0", ",", "0", ",", "0"}], "]"}]}], "\[Equal]", "0"}],
              ",", 
             RowBox[{
              RowBox[{
               RowBox[{"S", "[", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}], ",", "0"}], "]"}], "+", 
               RowBox[{"T", "[", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}], ",", "0"}], "]"}]}], "\[Equal]", "0"}], 
             ",", 
             RowBox[{
              RowBox[{
               RowBox[{"S", "[", 
                RowBox[{"1", ",", "0", ",", "0"}], "]"}], "+", 
               RowBox[{"T", "[", 
                RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "\[Equal]", "0"}],
              ",", 
             RowBox[{
              RowBox[{
               RowBox[{"S", "[", 
                RowBox[{"1", ",", "1", ",", "0"}], "]"}], "+", 
               RowBox[{"T", "[", 
                RowBox[{"1", ",", "1", ",", "0"}], "]"}]}], "\[Equal]", "0"}],
              ",", 
             RowBox[{
              RowBox[{
               RowBox[{"S", "[", 
                RowBox[{"0", ",", "0", ",", "1"}], "]"}], "+", 
               RowBox[{"T", "[", 
                RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "\[Equal]", 
              "0"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               SubscriptBox["f", 
                RowBox[{"0", ",", "0", ",", "0"}]], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               SubscriptBox["x", "1"], ",", 
               SubscriptBox["x", "2"], ",", 
               SubscriptBox["x", "3"], ",", "t"}], "]"}], ",", 
             RowBox[{
              SuperscriptBox[
               SubscriptBox["v", "1"], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               SubscriptBox["x", "1"], ",", 
               SubscriptBox["x", "2"], ",", 
               SubscriptBox["x", "3"], ",", "t"}], "]"}], ",", 
             RowBox[{
              SuperscriptBox[
               SubscriptBox["v", "2"], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               SubscriptBox["x", "1"], ",", 
               SubscriptBox["x", "2"], ",", 
               SubscriptBox["x", "3"], ",", "t"}], "]"}], ",", 
             RowBox[{
              SuperscriptBox[
               SubscriptBox["v", "3"], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               SubscriptBox["x", "1"], ",", 
               SubscriptBox["x", "2"], ",", 
               SubscriptBox["x", "3"], ",", "t"}], "]"}], ",", 
             RowBox[{
              SuperscriptBox["\[Theta]", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               SubscriptBox["x", "1"], ",", 
               SubscriptBox["x", "2"], ",", 
               SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "}"}]}], "]"}], 
         "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["f", 
          RowBox[{"l_", ",", "m_", ",", "n_"}]], "/;", 
         RowBox[{"l", ">", "0"}]}], "\[RuleDelayed]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Kn", " ", 
           RowBox[{
            SubscriptBox["f", 
             RowBox[{"l", ",", "m", ",", "n"}]], "[", 
            RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}], "&"}], 
         ")"}]}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Rules", " ", "to", " ", "replace", " ", "the", " ", "time", " ", 
     "derivatives"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RuleCsv", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"i_", ",", "j_", ",", "k_", ",", "1"}], "]"}], "[", 
          SubscriptBox["f", 
           RowBox[{"0", ",", "0", ",", "0"}]], "]"}], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
          "Csv", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "1"], ",", "i"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "2"], ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "3"], ",", "k"}], "}"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"i_", ",", "j_", ",", "k_", ",", "1"}], "]"}], "[", 
          SubscriptBox["v", "1"], "]"}], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
          "Csv", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "1"], ",", "i"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "2"], ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "3"], ",", "k"}], "}"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"i_", ",", "j_", ",", "k_", ",", "1"}], "]"}], "[", 
          SubscriptBox["v", "2"], "]"}], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
          "Csv", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "1"], ",", "i"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "2"], ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "3"], ",", "k"}], "}"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"i_", ",", "j_", ",", "k_", ",", "1"}], "]"}], "[", 
          SubscriptBox["v", "3"], "]"}], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
          "Csv", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "1"], ",", "i"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "2"], ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "3"], ",", "k"}], "}"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"i_", ",", "j_", ",", "k_", ",", "1"}], "]"}], "[", 
          "\[Theta]", "]"}], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
          "Csv", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "1"], ",", "i"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "2"], ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "3"], ",", "k"}], "}"}]}], "]"}]}]}], "}"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.782610287102242*^9, 3.782610364937839*^9}, {
  3.78261049547721*^9, 3.782610496795773*^9}, {3.7839840143560467`*^9, 
  3.783984038076449*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"d42f9a67-c252-4a4f-ae99-18953a7b8a84"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], 
    SubsuperscriptBox["f", 
     RowBox[{"l", ",", "m", ",", "n"}], 
     RowBox[{"(", "2", ")"}]]}], "+", 
   SubsuperscriptBox["S", 
    RowBox[{"l", ",", "m", ",", "n"}], 
    RowBox[{"(", "2", ")"}]], "+", 
   SubsuperscriptBox["T", 
    RowBox[{"l", ",", "m", ",", "n"}], 
    RowBox[{"(", "2", ")"}]]}], TraditionalForm]],
 FormatType->
  "TraditionalForm",ExpressionUUID->"460056e0-89b2-4736-8552-23b5f8fbca3e"]], \
"Subsection",
 CellChangeTimes->{{3.7825478421404057`*^9, 3.7825478742130833`*^9}, {
  3.7825485457208157`*^9, 
  3.782548569343461*^9}},ExpressionUUID->"fc07b21c-94bc-4a15-99d4-\
961b9b8266cc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "term", " ", "in", " ", "the", " ", "parentheses", " ", "in", 
    " ", "equation", " ", 
    RowBox[{"(", "3.31", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fST2", "=", "f2"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"l", "=", "1"}], ",", 
     RowBox[{"l", "\[LessEqual]", "2"}], ",", 
     RowBox[{"l", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{"-", "l"}]}], ",", 
       RowBox[{"m", "\[LessEqual]", "l"}], ",", 
       RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"n", "=", 
          RowBox[{"n0", "[", "l", "]"}]}], ",", 
         RowBox[{"n", "\[LessEqual]", 
          RowBox[{
           RowBox[{"Floor", "[", 
            FractionBox[
             RowBox[{"Deg", "-", "l"}], "2"], "]"}], "-", "2"}]}], ",", 
         RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"fST2", "\[LeftDoubleBracket]", 
           RowBox[{"Idx", "[", 
            RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
           "\[RightDoubleBracket]"}], "=", 
          RowBox[{"Chop", "[", 
           RowBox[{"Expand", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["\[PartialD]", "t"], 
                RowBox[{"W1", "\[LeftDoubleBracket]", 
                 RowBox[{"Idx", "[", 
                  RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
                 "\[RightDoubleBracket]"}]}], "/.", "RuleCsv"}], ")"}], "+", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SubscriptBox["\[PartialD]", "t"], 
                   RowBox[{"W2", "\[LeftDoubleBracket]", 
                    RowBox[{"Idx", "[", 
                    RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
                    "\[RightDoubleBracket]"}]}], "+", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"S", "[", 
                    RowBox[{"l", ",", "m", ",", "n"}], "]"}], "+", 
                    RowBox[{"T", "[", 
                    RowBox[{"l", ",", "m", ",", "n"}], "]"}]}], "/.", 
                    RowBox[{
                    SubscriptBox["f", 
                    RowBox[{"l_", ",", "m_", ",", "n_"}]], "\[RuleDelayed]", 
                    RowBox[{"f2func", "\[LeftDoubleBracket]", 
                    RowBox[{"Idx", "[", 
                    RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
                    "\[RightDoubleBracket]"}]}]}], ")"}]}], "/.", "Rules"}], "/.", 
                RowBox[{
                "RuleCsv", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}]}], "/.", "RuleV\[CapitalTheta]"}], 
              ")"}]}], "]"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
      "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7825479206654778`*^9, 3.782547949343169*^9}, {
   3.782547988545761*^9, 3.782547999643939*^9}, {3.782548579369968*^9, 
   3.782548630677464*^9}, {3.7825571765320053`*^9, 3.782557185199752*^9}, {
   3.782557222557775*^9, 3.782557224584004*^9}, {3.7825573427713137`*^9, 
   3.782557369873959*^9}, {3.782557412095994*^9, 3.7825574675453997`*^9}, {
   3.782557590744442*^9, 3.782557594140222*^9}, {3.782603388949827*^9, 
   3.7826034105925283`*^9}, 3.782603448775896*^9, {3.78260348666111*^9, 
   3.782603543314012*^9}, {3.782604609167123*^9, 3.7826046115182133`*^9}, {
   3.782604710045424*^9, 3.782604712645512*^9}, {3.7826052835684032`*^9, 
   3.782605291382329*^9}, {3.782605625018133*^9, 3.782605648282228*^9}, {
   3.783984118064024*^9, 3.7839841300031967`*^9}, {3.784117669951136*^9, 
   3.784117672934886*^9}},ExpressionUUID->"4ea5055d-d309-4bd4-988a-\
debba3eb7159"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "General form of ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["f", 
    RowBox[{"l", ",", "m", ",", "n"}], 
    RowBox[{"(", "3", ")"}]], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "92886144-6292-4c0e-a7ab-405739b15d41"]
}], "Subsection",
 CellChangeTimes->{{3.782557786747958*^9, 
  3.782557797433518*^9}},ExpressionUUID->"2eaf4bdb-c8ce-4823-87ba-\
f203fd80f72d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Equation", " ", 
    RowBox[{"(", "3.31", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"f3", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"l", ",", "0", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "l"}], ",", "l"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", 
         RowBox[{
          RowBox[{"Floor", "[", 
           FractionBox[
            RowBox[{"Deg", "-", "l"}], "2"], "]"}], "-", "2"}]}], "}"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"l", "=", "1"}], ",", 
     RowBox[{"l", "\[LessEqual]", "2"}], ",", 
     RowBox[{"l", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{"-", "l"}]}], ",", 
       RowBox[{"m", "\[LessEqual]", "l"}], ",", 
       RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"n", "=", 
          RowBox[{"n0", "[", "l", "]"}]}], ",", 
         RowBox[{"n", "\[LessEqual]", 
          RowBox[{
           RowBox[{"Floor", "[", 
            FractionBox[
             RowBox[{"Deg", "-", "l"}], "2"], "]"}], "-", "2"}]}], ",", 
         RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"f3", "\[LeftDoubleBracket]", 
           RowBox[{"Idx", "[", 
            RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
           "\[RightDoubleBracket]"}], "=", 
          RowBox[{"Chop", "[", 
           RowBox[{"Expand", "[", 
            RowBox[{
             FractionBox["\[Mu]", 
              RowBox[{
               RowBox[{"F", "[", 
                RowBox[{"0", ",", "0", ",", "0"}], "]"}], 
               "\[CapitalTheta]"}]], 
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"n1", "=", 
                RowBox[{"n0", "[", "l", "]"}]}], 
               RowBox[{
                RowBox[{"n0", "[", "l", "]"}], "+", 
                RowBox[{"Length", "[", 
                 RowBox[{"CoefB", "\[LeftDoubleBracket]", 
                  RowBox[{"l", "+", "1"}], "\[RightDoubleBracket]"}], "]"}], 
                "-", "3"}]], 
              RowBox[{
               RowBox[{"GetB", "[", 
                RowBox[{"l", ",", "n", ",", "n1"}], "]"}], 
               SuperscriptBox["\[CapitalTheta]", 
                RowBox[{"n", "-", "n1"}]], 
               RowBox[{"fST2", "\[LeftDoubleBracket]", 
                RowBox[{"Idx", "[", 
                 RowBox[{"l", ",", "m", ",", "n1"}], "]"}], 
                "\[RightDoubleBracket]"}]}]}]}], "]"}], "]"}]}]}], 
        "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7825578038627043`*^9, 3.782557885458797*^9}, 
   3.782560160366393*^9, {3.78260349975219*^9, 3.78260350504246*^9}, {
   3.78260363324824*^9, 3.782603647462199*^9}, {3.7826036828407097`*^9, 
   3.7826036996300993`*^9}, 3.782604372073902*^9, {3.782604781102006*^9, 
   3.78260478140672*^9}, {3.7826054886931973`*^9, 3.782605528015605*^9}, {
   3.7826058748304167`*^9, 3.78260589000593*^9}, 3.782685135590275*^9, {
   3.783984142726536*^9, 3.783984151307432*^9}, {3.784117675034458*^9, 
   3.784117677582383*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"877d107f-fc47-4699-9446-5fb7b8a5f17c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Replace time derivatives of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", 
    RowBox[{"1", ",", "m", ",", "n"}]], TraditionalForm]],ExpressionUUID->
  "16b65875-e579-4807-9c01-b23c0ff5d401"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", 
    RowBox[{"2", ",", "m", ",", "n"}]], TraditionalForm]],ExpressionUUID->
  "700bce62-e030-4e9e-8ea8-a3080b6a403d"]
}], "Subsection",
 CellChangeTimes->{{3.782514538519968*^9, 3.782514542175438*^9}, 
   3.782560057471916*^9},ExpressionUUID->"68cd4330-e332-4f60-94df-\
0616830bb444"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Equation", " ", 
    RowBox[{"(", "3.35", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Coef\[Lambda]1", "=", 
     RowBox[{
      RowBox[{"CoefC", " ", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", 
        RowBox[{"2", ";;"}]}], "\[RightDoubleBracket]"}], "CoefD"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Coef\[Lambda]1", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
      "/=", 
     RowBox[{"GetA", "[", 
      RowBox[{"1", ",", "1"}], "]"}]}], ";", 
    RowBox[{
     RowBox[{
     "Coef\[Lambda]1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
      "/=", 
     RowBox[{"GetA", "[", 
      RowBox[{"2", ",", "0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dtf1m12", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"Total", "[", 
            RowBox[{
            "Coef\[Lambda]1", "\[LeftDoubleBracket]", "1", 
             "\[RightDoubleBracket]"}], "]"}]}], ")"}], 
         RowBox[{"-", "1"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "Kn"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox[
               RowBox[{
                RowBox[{"F", "[", 
                 RowBox[{"0", ",", "0", ",", "0"}], "]"}], 
                "\[CapitalTheta]"}], "\[Mu]"], 
              FractionBox[
               RowBox[{"F", "[", 
                RowBox[{"1", ",", "m", ",", "1"}], "]"}], 
               RowBox[{"GetA", "[", 
                RowBox[{"1", ",", "1"}], "]"}]]}], "-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"T", "[", 
                RowBox[{"1", ",", "m", ",", "1"}], "]"}], "/.", 
               RowBox[{
                RowBox[{
                 SubscriptBox["f", 
                  RowBox[{"l0_", ",", "m0_", ",", "n0_"}]], "/;", 
                 RowBox[{
                  RowBox[{"l0", "\[NotEqual]", "0"}], "||", 
                  RowBox[{"m0", "\[NotEqual]", "0"}], "||", 
                  RowBox[{"n0", "\[NotEqual]", "0"}]}]}], "\[Rule]", 
                RowBox[{"(", 
                 RowBox[{"0", "&"}], ")"}]}]}], ")"}]}], ")"}]}], "+", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox[
              RowBox[{
               RowBox[{"F", "[", 
                RowBox[{"0", ",", "0", ",", "0"}], "]"}], "\[CapitalTheta]"}],
               "\[Mu]"], 
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"n", "=", "2"}], 
               RowBox[{
                RowBox[{"Floor", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"Deg", "-", "1"}], ")"}], "/", "2"}], "]"}], "-", 
                "2"}]], 
              RowBox[{
               RowBox[{"a", "\[LeftDoubleBracket]", 
                RowBox[{"2", ",", "2", ",", 
                 RowBox[{"n", "+", "1"}]}], "\[RightDoubleBracket]"}], 
               SuperscriptBox["\[CapitalTheta]", 
                RowBox[{"1", "-", "n"}]], 
               RowBox[{"f2", "\[LeftDoubleBracket]", 
                RowBox[{"Idx", "[", 
                 RowBox[{"1", ",", "m", ",", "n"}], "]"}], 
                "\[RightDoubleBracket]"}]}]}]}], "-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"S", "[", 
                 RowBox[{"1", ",", "m", ",", "1"}], "]"}], "+", 
                RowBox[{"T", "[", 
                 RowBox[{"1", ",", "m", ",", "1"}], "]"}]}], "/.", 
               RowBox[{
                SubscriptBox["f", 
                 RowBox[{"l0_", ",", "m0_", ",", "n0_"}]], "\[RuleDelayed]", 
                RowBox[{"f1func", "\[LeftDoubleBracket]", 
                 RowBox[{"Idx", "[", 
                  RowBox[{"l0", ",", "m0", ",", "n0"}], "]"}], 
                 "\[RightDoubleBracket]"}]}]}], "/.", "RuleCsv"}], ")"}]}], 
           ")"}], "+", 
          RowBox[{"Kn", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox[
               RowBox[{
                RowBox[{"F", "[", 
                 RowBox[{"0", ",", "0", ",", "0"}], "]"}], 
                "\[CapitalTheta]"}], "\[Mu]"], 
              RowBox[{
               UnderoverscriptBox["\[Sum]", 
                RowBox[{"n", "=", "2"}], 
                RowBox[{
                 RowBox[{"Floor", "[", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"Deg", "-", "1"}], ")"}], "/", "2"}], "]"}], "-", 
                 "3"}]], 
               RowBox[{
                RowBox[{"a", "\[LeftDoubleBracket]", 
                 RowBox[{"2", ",", "2", ",", 
                  RowBox[{"n", "+", "1"}]}], "\[RightDoubleBracket]"}], 
                SuperscriptBox["\[CapitalTheta]", 
                 RowBox[{"1", "-", "n"}]], 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"f3", "\[LeftDoubleBracket]", 
                   RowBox[{"Idx", "[", 
                    RowBox[{"1", ",", "m", ",", "n"}], "]"}], 
                   "\[RightDoubleBracket]"}], "/.", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    SubscriptBox["f", 
                    RowBox[{"1", ",", "m", ",", "1"}]], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{
                    SubscriptBox["x", "1"], ",", 
                    SubscriptBox["x", "2"], ",", 
                    SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[Rule]", 
                   "0"}]}], ")"}]}]}]}], "-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"S", "[", 
                  RowBox[{"1", ",", "m", ",", "1"}], "]"}], "+", 
                 RowBox[{"T", "[", 
                  RowBox[{"1", ",", "m", ",", "1"}], "]"}]}], "/.", 
                RowBox[{
                 SubscriptBox["f", 
                  RowBox[{"l0_", ",", "m0_", ",", "n0_"}]], "\[RuleDelayed]", 
                 
                 RowBox[{"f2func", "\[LeftDoubleBracket]", 
                  RowBox[{"Idx", "[", 
                   RowBox[{"l0", ",", "m0", ",", "n0"}], "]"}], 
                  "\[RightDoubleBracket]"}]}]}], "/.", 
               "RuleV\[CapitalTheta]"}], ")"}]}], ")"}]}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dtf2m02", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"Total", "[", 
            RowBox[{
            "Coef\[Lambda]1", "\[LeftDoubleBracket]", "2", 
             "\[RightDoubleBracket]"}], "]"}]}], ")"}], 
         RowBox[{"-", "1"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "Kn"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox[
               RowBox[{
                RowBox[{"F", "[", 
                 RowBox[{"0", ",", "0", ",", "0"}], "]"}], 
                "\[CapitalTheta]"}], "\[Mu]"], 
              FractionBox[
               RowBox[{"F", "[", 
                RowBox[{"2", ",", "m", ",", "0"}], "]"}], 
               RowBox[{"GetA", "[", 
                RowBox[{"2", ",", "0"}], "]"}]]}], "-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"T", "[", 
                RowBox[{"2", ",", "m", ",", "0"}], "]"}], "/.", 
               RowBox[{
                RowBox[{
                 SubscriptBox["f", 
                  RowBox[{"l0_", ",", "m0_", ",", "n0_"}]], "/;", 
                 RowBox[{
                  RowBox[{"l0", "\[NotEqual]", "0"}], "||", 
                  RowBox[{"m0", "\[NotEqual]", "0"}], "||", 
                  RowBox[{"n0", "\[NotEqual]", "0"}]}]}], "\[Rule]", 
                RowBox[{"(", 
                 RowBox[{"0", "&"}], ")"}]}]}], ")"}]}], ")"}]}], "+", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox[
              RowBox[{
               RowBox[{"F", "[", 
                RowBox[{"0", ",", "0", ",", "0"}], "]"}], "\[CapitalTheta]"}],
               "\[Mu]"], 
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"n", "=", "1"}], 
               RowBox[{
                RowBox[{"Floor", "[", 
                 RowBox[{"Deg", "/", "2"}], "]"}], "-", "2"}]], 
              RowBox[{
               RowBox[{"a", "\[LeftDoubleBracket]", 
                RowBox[{"3", ",", "1", ",", 
                 RowBox[{"n", "+", "1"}]}], "\[RightDoubleBracket]"}], 
               SuperscriptBox["\[CapitalTheta]", 
                RowBox[{"-", "n"}]], 
               RowBox[{"f2", "\[LeftDoubleBracket]", 
                RowBox[{"Idx", "[", 
                 RowBox[{"2", ",", "m", ",", "n"}], "]"}], 
                "\[RightDoubleBracket]"}]}]}]}], "-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"S", "[", 
                 RowBox[{"2", ",", "m", ",", "0"}], "]"}], "+", 
                RowBox[{"T", "[", 
                 RowBox[{"2", ",", "m", ",", "0"}], "]"}]}], "/.", 
               RowBox[{
                SubscriptBox["f", 
                 RowBox[{"l0_", ",", "m0_", ",", "n0_"}]], "\[RuleDelayed]", 
                RowBox[{"f1func", "\[LeftDoubleBracket]", 
                 RowBox[{"Idx", "[", 
                  RowBox[{"l0", ",", "m0", ",", "n0"}], "]"}], 
                 "\[RightDoubleBracket]"}]}]}], "/.", "RuleCsv"}], ")"}]}], 
           ")"}], "+", 
          RowBox[{"Kn", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox[
               RowBox[{
                RowBox[{"F", "[", 
                 RowBox[{"0", ",", "0", ",", "0"}], "]"}], 
                "\[CapitalTheta]"}], "\[Mu]"], 
              RowBox[{
               UnderoverscriptBox["\[Sum]", 
                RowBox[{"n", "=", "1"}], 
                RowBox[{
                 RowBox[{"Floor", "[", 
                  RowBox[{"Deg", "/", "2"}], "]"}], "-", "3"}]], 
               RowBox[{
                RowBox[{"a", "\[LeftDoubleBracket]", 
                 RowBox[{"3", ",", "1", ",", 
                  RowBox[{"n", "+", "1"}]}], "\[RightDoubleBracket]"}], 
                SuperscriptBox["\[CapitalTheta]", 
                 RowBox[{"-", "n"}]], 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"f3", "\[LeftDoubleBracket]", 
                   RowBox[{"Idx", "[", 
                    RowBox[{"2", ",", "m", ",", "n"}], "]"}], 
                   "\[RightDoubleBracket]"}], "/.", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    SubscriptBox["f", 
                    RowBox[{"2", ",", "m", ",", "0"}]], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{
                    SubscriptBox["x", "1"], ",", 
                    SubscriptBox["x", "2"], ",", 
                    SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[Rule]", 
                   "0"}]}], ")"}]}]}]}], "-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"S", "[", 
                  RowBox[{"2", ",", "m", ",", "0"}], "]"}], "+", 
                 RowBox[{"T", "[", 
                  RowBox[{"2", ",", "m", ",", "0"}], "]"}]}], "/.", 
                RowBox[{
                 SubscriptBox["f", 
                  RowBox[{"l0_", ",", "m0_", ",", "n0_"}]], "\[RuleDelayed]", 
                 
                 RowBox[{"f2func", "\[LeftDoubleBracket]", 
                  RowBox[{"Idx", "[", 
                   RowBox[{"l0", ",", "m0", ",", "n0"}], "]"}], 
                  "\[RightDoubleBracket]"}]}]}], "/.", 
               "RuleV\[CapitalTheta]"}], ")"}]}], ")"}]}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]}], ";"}]}]}]], "Input",\

 CellChangeTimes->{{3.7824499172075243`*^9, 3.782449966192815*^9}, {
   3.782450038832019*^9, 3.7824500487704906`*^9}, {3.7824500903007183`*^9, 
   3.782450139594895*^9}, {3.7824502383174553`*^9, 3.7824503450929213`*^9}, {
   3.782450375886779*^9, 3.7824504891994677`*^9}, {3.7824505327366323`*^9, 
   3.782450540561452*^9}, {3.782450609064886*^9, 3.782450611077667*^9}, {
   3.7824507131475286`*^9, 3.782450744213183*^9}, {3.7824508587896214`*^9, 
   3.78245086778303*^9}, {3.782450924672386*^9, 3.78245092650443*^9}, {
   3.782450960990561*^9, 3.782451001342245*^9}, {3.782451164605369*^9, 
   3.782451230250448*^9}, {3.782451288589704*^9, 3.7824513204979467`*^9}, {
   3.782451411365561*^9, 3.78245146441038*^9}, {3.782466938234667*^9, 
   3.7824670347638187`*^9}, {3.782473845632629*^9, 3.782473845994141*^9}, {
   3.7824738919203157`*^9, 3.78247389239706*^9}, {3.7825581993173513`*^9, 
   3.7825582096342287`*^9}, {3.7825587297604713`*^9, 3.78255873375669*^9}, {
   3.782558787754345*^9, 3.782558798473051*^9}, 3.782558888168083*^9, {
   3.782559327402934*^9, 3.782559540600061*^9}, {3.782559576959165*^9, 
   3.782559599784534*^9}, {3.782559739751131*^9, 3.782559941693861*^9}, {
   3.7825599944422407`*^9, 3.7825600328627167`*^9}, {3.78260504163727*^9, 
   3.7826050452562237`*^9}, {3.78268530713301*^9, 3.782685342423621*^9}, {
   3.782686060326686*^9, 3.78268606648302*^9}, {3.782686105494115*^9, 
   3.782686108638134*^9}, {3.7826861683785*^9, 3.782686180695012*^9}, {
   3.783983601143815*^9, 3.783983603331086*^9}, {3.783984189567958*^9, 
   3.783984194124872*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"161ab294-19bc-4e35-9f7f-824744ea1a87"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Make", " ", "replacement"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Rules2", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"i_", ",", "j_", ",", "k_", ",", "1"}], "]"}], "[", 
          SubscriptBox["f", 
           RowBox[{"1", ",", "m_", ",", "1"}]], "]"}], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"Dtf1m12", "\[LeftDoubleBracket]", 
           RowBox[{"m", "+", "2"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "1"], ",", "i"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "2"], ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "3"], ",", "k"}], "}"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"i_", ",", "j_", ",", "k_", ",", "1"}], "]"}], "[", 
          SubscriptBox["f", 
           RowBox[{"2", ",", "m_", ",", "0"}]], "]"}], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"Dtf2m02", "\[LeftDoubleBracket]", 
           RowBox[{"m", "+", "3"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "1"], ",", "i"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "2"], ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "3"], ",", "k"}], "}"}]}], "]"}]}]}], "}"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"l", "=", "1"}], ",", 
     RowBox[{"l", "\[LessEqual]", "2"}], ",", 
     RowBox[{"l", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{"-", "l"}]}], ",", 
       RowBox[{"m", "\[LessEqual]", "l"}], ",", 
       RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"n", "=", 
          RowBox[{"n0", "[", "l", "]"}]}], ",", 
         RowBox[{"n", "\[LessEqual]", 
          RowBox[{
           RowBox[{"Floor", "[", 
            FractionBox[
             RowBox[{"Deg", "-", "l"}], "2"], "]"}], "-", "2"}]}], ",", 
         RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"f3", "\[LeftDoubleBracket]", 
           RowBox[{"Idx", "[", 
            RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
           "\[RightDoubleBracket]"}], "=", 
          RowBox[{"Chop", "[", 
           RowBox[{"Expand", "[", 
            RowBox[{
             RowBox[{"f3", "\[LeftDoubleBracket]", 
              RowBox[{"Idx", "[", 
               RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
              "\[RightDoubleBracket]"}], "/.", "Rules2"}], "]"}], "]"}]}]}], 
        "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.782560093097171*^9, 3.78256013751794*^9}, {
  3.782560186864614*^9, 3.78256020267*^9}, {3.782605571543682*^9, 
  3.782605587891658*^9}, {3.78260591962316*^9, 3.782605941745714*^9}, {
  3.782685050519854*^9, 3.782685069023307*^9}, {3.7839842106132708`*^9, 
  3.7839842164424667`*^9}, {3.784118180242704*^9, 
  3.784118183225606*^9}},ExpressionUUID->"c3a568b3-a2b8-404c-bfa6-\
8fa1492c778e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["R13 equations (Section 3.3.2)", "Section",
 CellChangeTimes->{{3.7826057096359262`*^9, 3.782605714109358*^9}, {
  3.783984448527854*^9, 
  3.7839844505006647`*^9}},ExpressionUUID->"b04d69b8-ee85-4ea1-8f51-\
e3a0f47c6016"],

Cell["\<\
This section provides the final form of R13 equations, including 1D linear \
equations and full 3D equations. Only equations for the stress tensor and the \
heat flux are provided.\
\>", "Text",
 CellChangeTimes->{{3.783984312569519*^9, 3.7839843160736637`*^9}, {
  3.783984363628944*^9, 
  3.783984432618834*^9}},ExpressionUUID->"fa02948b-0b46-4915-9399-\
5c0cd9b5c8fb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Equations", " ", 
    RowBox[{"(", "3.39", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"LHS", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "t"], 
         RowBox[{"F", "[", 
          RowBox[{"l", ",", "m", ",", "n"}], "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "Kn"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"T", "[", 
            RowBox[{"l", ",", "m", ",", "n"}], "]"}], "/.", 
           RowBox[{
            RowBox[{
             SubscriptBox["f", 
              RowBox[{"l0_", ",", "m0_", ",", "n0_"}]], "/;", 
             RowBox[{
              RowBox[{"l0", "\[NotEqual]", "0"}], "||", 
              RowBox[{"m0", "\[NotEqual]", "0"}], "||", 
              RowBox[{"n0", "\[NotEqual]", "0"}]}]}], "\[Rule]", 
            RowBox[{"(", 
             RowBox[{"0", "&"}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"S", "[", 
             RowBox[{"l", ",", "m", ",", "n"}], "]"}], "+", 
            RowBox[{"T", "[", 
             RowBox[{"l", ",", "m", ",", "n"}], "]"}]}], "/.", 
           RowBox[{
            SubscriptBox["f", 
             RowBox[{"l0_", ",", "m0_", ",", "n0_"}]], "\[RuleDelayed]", 
            RowBox[{"f1func", "\[LeftDoubleBracket]", 
             RowBox[{"Idx", "[", 
              RowBox[{"l0", ",", "m0", ",", "n0"}], "]"}], 
             "\[RightDoubleBracket]"}]}]}], "/.", "RuleCsv"}], ")"}], "+", 
        RowBox[{"Kn", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"S", "[", 
              RowBox[{"l", ",", "m", ",", "n"}], "]"}], "+", 
             RowBox[{"T", "[", 
              RowBox[{"l", ",", "m", ",", "n"}], "]"}]}], "/.", 
            RowBox[{
             SubscriptBox["f", 
              RowBox[{"l0_", ",", "m0_", ",", "n0_"}]], "\[RuleDelayed]", 
             RowBox[{"f2func", "\[LeftDoubleBracket]", 
              RowBox[{"Idx", "[", 
               RowBox[{"l0", ",", "m0", ",", "n0"}], "]"}], 
              "\[RightDoubleBracket]"}]}]}], "/.", "RuleV\[CapitalTheta]"}], 
          ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"l", ",", "1", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "l"}], ",", "l"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"2", "-", "l"}], ",", 
         RowBox[{"2", "-", "l"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GetLHS", "[", 
      RowBox[{"l_", ",", "m_"}], "]"}], ":=", 
     RowBox[{"LHS", "\[LeftDoubleBracket]", 
      RowBox[{"l", ",", 
       RowBox[{"m", "+", "l", "+", "1"}], ",", "1"}], 
      "\[RightDoubleBracket]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RHS", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"F", "[", 
           RowBox[{"0", ",", "0", ",", "0"}], "]"}], "\[CapitalTheta]"}], 
         RowBox[{"\[Mu]", " ", "Kn"}]], 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"F", "[", 
            RowBox[{"l", ",", "m", ",", "n"}], "]"}], 
           RowBox[{"GetA", "[", 
            RowBox[{"l", ",", "n"}], "]"}]], "+", 
          RowBox[{"Kn", 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"n1", "=", 
              RowBox[{"n0", "[", "l", "]"}]}], 
             RowBox[{
              RowBox[{"Length", "[", 
               RowBox[{"f2", "\[LeftDoubleBracket]", 
                RowBox[{
                 RowBox[{"l", "+", "1"}], ",", "1"}], 
                "\[RightDoubleBracket]"}], "]"}], "-", "1"}]], 
            RowBox[{
             RowBox[{"a", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"l", "+", "1"}], ",", 
               RowBox[{"n", "+", "1"}], ",", 
               RowBox[{"n1", "+", "1"}]}], "\[RightDoubleBracket]"}], 
             SuperscriptBox["\[CapitalTheta]", 
              RowBox[{
               RowBox[{"n0", "[", "l", "]"}], "-", "1", "-", "n1"}]], 
             RowBox[{"f2", "\[LeftDoubleBracket]", 
              RowBox[{"Idx", "[", 
               RowBox[{"l", ",", "m", ",", "n1"}], "]"}], 
              "\[RightDoubleBracket]"}]}]}]}], "+", 
          RowBox[{
           SuperscriptBox["Kn", "2"], 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"n1", "=", 
              RowBox[{"n0", "[", "l", "]"}]}], 
             RowBox[{
              RowBox[{"Length", "[", 
               RowBox[{"f2", "\[LeftDoubleBracket]", 
                RowBox[{
                 RowBox[{"l", "+", "1"}], ",", "1"}], 
                "\[RightDoubleBracket]"}], "]"}], "-", "2"}]], 
            RowBox[{
             RowBox[{"a", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"l", "+", "1"}], ",", 
               RowBox[{"n", "+", "1"}], ",", 
               RowBox[{"n1", "+", "1"}]}], "\[RightDoubleBracket]"}], 
             SuperscriptBox["\[CapitalTheta]", 
              RowBox[{
               RowBox[{"n0", "[", "l", "]"}], "-", "1", "-", "n1"}]], " ", 
             RowBox[{"f3", "\[LeftDoubleBracket]", 
              RowBox[{"Idx", "[", 
               RowBox[{"l", ",", "m", ",", "n1"}], "]"}], 
              "\[RightDoubleBracket]"}]}]}]}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"l", ",", "1", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "l"}], ",", "l"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"2", "-", "l"}], ",", 
         RowBox[{"2", "-", "l"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GetRHS", "[", 
      RowBox[{"l_", ",", "m_"}], "]"}], ":=", 
     RowBox[{"RHS", "\[LeftDoubleBracket]", 
      RowBox[{"l", ",", 
       RowBox[{"m", "+", "l", "+", "1"}], ",", "1"}], 
      "\[RightDoubleBracket]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7826058103307343`*^9, 3.782605846570569*^9}, {
   3.78260596707752*^9, 3.78260597888979*^9}, {3.782606035822105*^9, 
   3.782606036803042*^9}, {3.782606204097077*^9, 3.7826062044307127`*^9}, {
   3.782685156117474*^9, 3.782685190155064*^9}, 3.7826852682437067`*^9, {
   3.7826863792152243`*^9, 3.78268637947968*^9}, {3.7839844362350683`*^9, 
   3.78398444199469*^9}},
 CellLabel->"In[70]:=",ExpressionUUID->"1281625e-3613-45fb-b8cd-59057eebc33c"],

Cell[CellGroupData[{

Cell["1D Linear equations", "Subsection",
 CellChangeTimes->{{3.782467975492885*^9, 
  3.782467977593027*^9}},ExpressionUUID->"c7552653-0108-4396-b1e7-\
63b67872d614"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Equationq", "=", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"GetLHS", "[", 
           RowBox[{"1", ",", "0"}], "]"}], "\[Equal]", 
          RowBox[{"GetRHS", "[", 
           RowBox[{"1", ",", "0"}], "]"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             SubscriptBox["f", 
              RowBox[{"l_", ",", "m_", ",", "n_"}]], "/;", 
             RowBox[{"m", "\[NotEqual]", "0"}]}], "\[RuleDelayed]", 
            RowBox[{"(", 
             RowBox[{"0", "&"}], ")"}]}], ",", 
           RowBox[{
            SubscriptBox["v", "1"], "\[Rule]", 
            RowBox[{"(", 
             RowBox[{"0", "&"}], ")"}]}], ",", 
           RowBox[{
            SubscriptBox["v", "2"], "\[Rule]", 
            RowBox[{"(", 
             RowBox[{"0", "&"}], ")"}]}]}], "}"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", 
              RowBox[{"i_", ",", "j_", ",", "k_", ",", "0"}], "]"}], "[", 
             "f_", "]"}], "[", 
            RowBox[{
             SubscriptBox["x", "1"], ",", 
             SubscriptBox["x", "2"], ",", 
             SubscriptBox["x", "3"], ",", "t"}], "]"}], "/;", 
           RowBox[{
            RowBox[{"i", "+", "j"}], ">", "0"}]}], "\[Rule]", "0"}], "}"}]}], 
       "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["f", 
           RowBox[{"0", ",", "0", ",", "0"}]], "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"1", "+", 
             RowBox[{"\[Epsilon]", " ", 
              RowBox[{"\[Rho]", "[", 
               RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}]}], 
            "&"}], ")"}]}], ",", 
         RowBox[{
          SubscriptBox["v", "3"], "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Epsilon]", " ", 
             RowBox[{"u", "[", 
              RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}], "&"}],
            ")"}]}], ",", 
         RowBox[{
          SubscriptBox["f", 
           RowBox[{"1", ",", "0", ",", "1"}]], "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "Kn"]}], 
             SqrtBox[
              FractionBox["2", "5"]], "\[Epsilon]", " ", 
             RowBox[{"q", "[", 
              RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}], "&"}],
            ")"}]}], ",", 
         RowBox[{
          SubscriptBox["f", 
           RowBox[{"2", ",", "0", ",", "0"}]], "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["1", "Kn"], 
             FractionBox[
              SqrtBox["3"], "2"], "\[Epsilon]", " ", 
             RowBox[{"\[Sigma]", "[", 
              RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}], "&"}],
            ")"}]}], ",", 
         RowBox[{"\[Theta]", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"1", "+", 
             RowBox[{"\[Epsilon]", " ", 
              RowBox[{"\[Theta]", "[", 
               RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}]}], 
            "&"}], ")"}]}]}], "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Epsilon]", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Expand", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"Equationq", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]", "\[Rule]", "1"}], ",", 
       RowBox[{"\[Mu]0", "\[Rule]", "1"}]}], "}"}]}], ",", 
    RowBox[{
     SuperscriptBox["q", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"], ",", 
      SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7824528767193336`*^9, 3.782452915276634*^9}, {
   3.782452983414185*^9, 3.7824530053978662`*^9}, {3.782453353398275*^9, 
   3.7824534981533613`*^9}, {3.782467217182455*^9, 3.782467233562723*^9}, {
   3.782468026219558*^9, 3.7824680319727077`*^9}, {3.782468067525939*^9, 
   3.782468095519596*^9}, {3.7824681850102177`*^9, 3.782468198884304*^9}, {
   3.7824692564934807`*^9, 3.782469258697867*^9}, {3.782469471384499*^9, 
   3.782469472655962*^9}, 3.782469555336321*^9, {3.782470910653131*^9, 
   3.782470918676382*^9}, {3.782472046806285*^9, 3.782472052067588*^9}, 
   3.782538718102756*^9, {3.7826110571294527`*^9, 3.7826110574172153`*^9}, {
   3.782611091013133*^9, 3.782611151815406*^9}, {3.7839843528918858`*^9, 
   3.783984354905774*^9}, {3.78411793788199*^9, 3.784117941584805*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"b155bd09-7c80-4e80-acba-d0fe196ef372"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["q", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"], ",", 
      SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
       "0.6314799074969125904946391296288008992990584959709778161041`32.\
88402561030623", " ", 
        RowBox[{"q", "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "Kn"]}], "-", 
     RowBox[{
     "2.4277669983856652901029189200042491521237151482854616286669`33.\
04115467322617", " ", 
      RowBox[{
       SuperscriptBox["\[Theta]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        SubscriptBox["x", "1"], ",", 
        SubscriptBox["x", "2"], ",", 
        SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "-", 
     RowBox[{
     "0.5982420234187007339450263427213028841280573031744551648517`33.\
0594611117575", " ", 
      RowBox[{
       SuperscriptBox["\[Sigma]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        SubscriptBox["x", "1"], ",", 
        SubscriptBox["x", "2"], ",", 
        SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "+", 
     RowBox[{
     "2.9722399220782228686983437173111204260094478527816970551197`32.\
990397527769225", " ", "Kn", " ", 
      RowBox[{
       SuperscriptBox["q", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        SubscriptBox["x", "1"], ",", 
        SubscriptBox["x", "2"], ",", 
        SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "+", 
     RowBox[{
     "0.2699841495189930918496977934070926354422101611125938722092`33.\
04742100159974", " ", "Kn", " ", 
      RowBox[{
       SuperscriptBox["u", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        SubscriptBox["x", "1"], ",", 
        SubscriptBox["x", "2"], ",", 
        SubscriptBox["x", "3"], ",", "t"}], "]"}]}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7841179251584873`*^9, 3.784117943291051*^9}},
 CellLabel->"Out[77]=",ExpressionUUID->"13b76c48-7831-4ced-bcba-ca5e778d2af1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Equation\[Sigma]", "=", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"GetLHS", "[", 
           RowBox[{"2", ",", "0"}], "]"}], "\[Equal]", 
          RowBox[{"GetRHS", "[", 
           RowBox[{"2", ",", "0"}], "]"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             SubscriptBox["f", 
              RowBox[{"l_", ",", "m_", ",", "n_"}]], "/;", 
             RowBox[{"m", "\[NotEqual]", "0"}]}], "\[RuleDelayed]", 
            RowBox[{"(", 
             RowBox[{"0", "&"}], ")"}]}], ",", 
           RowBox[{
            SubscriptBox["v", "1"], "\[Rule]", 
            RowBox[{"(", 
             RowBox[{"0", "&"}], ")"}]}], ",", 
           RowBox[{
            SubscriptBox["v", "2"], "\[Rule]", 
            RowBox[{"(", 
             RowBox[{"0", "&"}], ")"}]}]}], "}"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", 
              RowBox[{"i_", ",", "j_", ",", "k_", ",", "0"}], "]"}], "[", 
             "f_", "]"}], "[", 
            RowBox[{
             SubscriptBox["x", "1"], ",", 
             SubscriptBox["x", "2"], ",", 
             SubscriptBox["x", "3"], ",", "t"}], "]"}], "/;", 
           RowBox[{
            RowBox[{"i", "+", "j"}], ">", "0"}]}], "\[Rule]", "0"}], "}"}]}], 
       "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["f", 
           RowBox[{"0", ",", "0", ",", "0"}]], "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"1", "+", 
             RowBox[{"\[Epsilon]", " ", 
              RowBox[{"\[Rho]", "[", 
               RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}]}], 
            "&"}], ")"}]}], ",", 
         RowBox[{
          SubscriptBox["v", "3"], "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Epsilon]", " ", 
             RowBox[{"u", "[", 
              RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}], "&"}],
            ")"}]}], ",", 
         RowBox[{
          SubscriptBox["f", 
           RowBox[{"1", ",", "0", ",", "1"}]], "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "Kn"]}], 
             SqrtBox[
              FractionBox["2", "5"]], "\[Epsilon]", " ", 
             RowBox[{"q", "[", 
              RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}], "&"}],
            ")"}]}], ",", 
         RowBox[{
          SubscriptBox["f", 
           RowBox[{"2", ",", "0", ",", "0"}]], "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["1", "Kn"], 
             FractionBox[
              SqrtBox["3"], "2"], "\[Epsilon]", " ", 
             RowBox[{"\[Sigma]", "[", 
              RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}], "&"}],
            ")"}]}], ",", 
         RowBox[{"\[Theta]", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"1", "+", 
             RowBox[{"\[Epsilon]", " ", 
              RowBox[{"\[Theta]", "[", 
               RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}]}], 
            "&"}], ")"}]}]}], "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Epsilon]", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Expand", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"Equation\[Sigma]", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]", "\[Rule]", "1"}], ",", 
       RowBox[{"\[Mu]0", "\[Rule]", "1"}]}], "}"}]}], ",", 
    RowBox[{
     SuperscriptBox["\[Sigma]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"], ",", 
      SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.782467193425111*^9, 3.782467194796033*^9}, {
   3.782468145236332*^9, 3.782468147856621*^9}, {3.782468208413941*^9, 
   3.7824682690315123`*^9}, {3.782469078552153*^9, 3.782469083351007*^9}, {
   3.782469329327764*^9, 3.782469329967226*^9}, {3.782472058536269*^9, 
   3.782472073628834*^9}, 3.7825387242825813`*^9, {3.782611197711672*^9, 
   3.7826111982565928`*^9}, 3.783984359505492*^9, {3.784117951020865*^9, 
   3.7841179548364477`*^9}},
 CellLabel->"In[78]:=",ExpressionUUID->"3e005c1c-7049-45d5-a1eb-7ea719a60477"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Sigma]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"], ",", 
      SubscriptBox["x", "3"], ",", "t"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
       "0.9579426478318281822110923569864090318045620220334821932363`30.\
333159823705554", " ", 
        RowBox[{"\[Sigma]", "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "Kn"]}], "-", 
     RowBox[{
     "0.3536763565498412681320225023124036803985787017418753815288`30.\
26325627248943", " ", 
      RowBox[{
       SuperscriptBox["q", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        SubscriptBox["x", "1"], ",", 
        SubscriptBox["x", "2"], ",", 
        SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "-", 
     RowBox[{
     "1.2977363020691655971218459628335981114310176157350563369196`30.\
49173980492989", " ", 
      RowBox[{
       SuperscriptBox["u", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        SubscriptBox["x", "1"], ",", 
        SubscriptBox["x", "2"], ",", 
        SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "+", 
     RowBox[{
     "0.2498862307926887941383268493992224483424104943808429755602`30.\
333159823705554", " ", "Kn", " ", 
      RowBox[{
       SuperscriptBox["\[Theta]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        SubscriptBox["x", "1"], ",", 
        SubscriptBox["x", "2"], ",", 
        SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "+", 
     RowBox[{
     "0.0173131253899415549569391953356254767387597674702894420029`30.\
333159823705554", " ", "Kn", " ", 
      RowBox[{
       SuperscriptBox["\[Rho]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        SubscriptBox["x", "1"], ",", 
        SubscriptBox["x", "2"], ",", 
        SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "+", 
     RowBox[{
     "1.2213628149938818121363214048315898362134535431162410265484`30.\
50086569286298", " ", "Kn", " ", 
      RowBox[{
       SuperscriptBox["\[Sigma]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        SubscriptBox["x", "1"], ",", 
        SubscriptBox["x", "2"], ",", 
        SubscriptBox["x", "3"], ",", "t"}], "]"}]}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.784117955431974*^9},
 CellLabel->"Out[79]=",ExpressionUUID->"3d6b97c0-2433-4905-9a01-fd49db9fe597"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3D equations", "Subsection",
 CellChangeTimes->{{3.782625015796629*^9, 
  3.78262501942634*^9}},ExpressionUUID->"b48b8e3a-2328-45c0-8fd1-\
78ec6861876c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Equation", " ", 
    RowBox[{"(", "3.2", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Replacement", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", 
        RowBox[{"0", ",", "0", ",", "0"}]], "\[RuleDelayed]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Rho]", "[", 
          RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}], "&"}], 
        ")"}]}], ",", 
      RowBox[{
       SubscriptBox["f", 
        RowBox[{"1", ",", "1", ",", "1"}]], "\[RuleDelayed]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           RowBox[{
            SqrtBox["5"], "Kn"}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["q", "1"], "[", 
             RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{
              SubscriptBox["q", "2"], "[", 
              RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}]}], 
           ")"}]}], "&"}], ")"}]}], ",", 
      RowBox[{
       SubscriptBox["f", 
        RowBox[{"1", ",", "0", ",", "1"}]], "\[RuleDelayed]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "Kn"]}], 
          SqrtBox[
           FractionBox["2", "5"]], 
          RowBox[{
           SubscriptBox["q", "3"], "[", 
           RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}], "&"}], 
        ")"}]}], ",", 
      RowBox[{
       SubscriptBox["f", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}], ",", "1"}]], "\[RuleDelayed]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            RowBox[{
             SqrtBox["5"], "Kn"}]]}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["q", "1"], "[", 
             RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{
              SubscriptBox["q", "2"], "[", 
              RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}]}], 
           ")"}]}], "&"}], ")"}]}], ",", 
      RowBox[{
       SubscriptBox["f", 
        RowBox[{"2", ",", "2", ",", "0"}]], "\[RuleDelayed]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           RowBox[{
            SqrtBox["2"], "Kn"}]], 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox["\[Sigma]", 
                RowBox[{"1", ",", "1"}]], "[", 
               RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}], "-", 
              RowBox[{
               SubscriptBox["\[Sigma]", 
                RowBox[{"2", ",", "2"}]], "[", 
               RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}], "2"],
             "-", 
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{
              SubscriptBox["\[Sigma]", 
               RowBox[{"1", ",", "2"}]], "[", 
              RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}]}], 
           ")"}]}], "&"}], ")"}]}], ",", 
      RowBox[{
       SubscriptBox["f", 
        RowBox[{"2", ",", "1", ",", "0"}]], "\[RuleDelayed]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            RowBox[{
             SqrtBox["2"], "Kn"}]]}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["\[Sigma]", 
              RowBox[{"1", ",", "3"}]], "[", 
             RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{
              SubscriptBox["\[Sigma]", 
               RowBox[{"2", ",", "3"}]], "[", 
              RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}]}], 
           ")"}]}], "&"}], ")"}]}], ",", 
      RowBox[{
       SubscriptBox["f", 
        RowBox[{"2", ",", "0", ",", "0"}]], "\[RuleDelayed]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox["3"], 
            RowBox[{"2", "Kn"}]]}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["\[Sigma]", 
              RowBox[{"1", ",", "1"}]], "[", 
             RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}], "+", 
            RowBox[{
             SubscriptBox["\[Sigma]", 
              RowBox[{"2", ",", "2"}]], "[", 
             RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}], 
           ")"}]}], "&"}], ")"}]}], ",", 
      RowBox[{
       SubscriptBox["f", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}], ",", "0"}]], "\[RuleDelayed]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           RowBox[{
            SqrtBox["2"], "Kn"}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["\[Sigma]", 
              RowBox[{"1", ",", "3"}]], "[", 
             RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{
              SubscriptBox["\[Sigma]", 
               RowBox[{"2", ",", "3"}]], "[", 
              RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}]}], 
           ")"}]}], "&"}], ")"}]}], ",", 
      RowBox[{
       SubscriptBox["f", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}], ",", "0"}]], "\[RuleDelayed]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           RowBox[{
            SqrtBox["2"], "Kn"}]], 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox["\[Sigma]", 
                RowBox[{"1", ",", "1"}]], "[", 
               RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}], "-", 
              RowBox[{
               SubscriptBox["\[Sigma]", 
                RowBox[{"2", ",", "2"}]], "[", 
               RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}], "2"],
             "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{
              SubscriptBox["\[Sigma]", 
               RowBox[{"1", ",", "2"}]], "[", 
              RowBox[{"#1", ",", "#2", ",", "#3", ",", "#4"}], "]"}]}]}], 
           ")"}]}], "&"}], ")"}]}], ",", 
      RowBox[{"\[Mu]0", "\[Rule]", 
       RowBox[{
        RowBox[{"\[Nu]", "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}], "/", 
        SuperscriptBox[
         RowBox[{"\[Theta]", "[", 
          RowBox[{
           SubscriptBox["x", "1"], ",", 
           SubscriptBox["x", "2"], ",", 
           SubscriptBox["x", "3"], ",", "t"}], "]"}], 
         RowBox[{
          FractionBox["1", "2"], "+", 
          FractionBox["2", 
           RowBox[{"\[Eta]", "-", "1"}]]}]]}]}]}], "}"}]}], ";"}]}]], "Input",\

 CellChangeTimes->{{3.78262479754108*^9, 3.782624834575932*^9}, 
   3.78262498318851*^9, {3.782625021471386*^9, 3.782625203471212*^9}, {
   3.782625242008799*^9, 3.7826253799095573`*^9}, {3.78262541547429*^9, 
   3.782625590649494*^9}, {3.78262586901334*^9, 3.78262588013694*^9}, {
   3.782625972634989*^9, 3.782625977145287*^9}, {3.782626013080241*^9, 
   3.782626035339974*^9}, {3.7826261237537117`*^9, 3.782626124535264*^9}, {
   3.7826261809208384`*^9, 3.782626181462945*^9}, {3.7839844996624928`*^9, 
   3.783984504597237*^9}, {3.784115336539215*^9, 3.784115355149631*^9}, {
   3.784117717350401*^9, 3.7841177180688677`*^9}, {3.784117983977461*^9, 
   3.784117984128171*^9}, {3.7841180488148003`*^9, 3.784118057788953*^9}, {
   3.7841180888448*^9, 3.78411814696772*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"c0cd7ab8-0fe5-4df2-a617-6cebc09d1b6c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["EQq", "3"], "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"GetLHS", "[", 
            RowBox[{"1", ",", "0"}], "]"}], "\[Equal]", 
           RowBox[{"GetRHS", "[", 
            RowBox[{"1", ",", "0"}], "]"}]}], "/.", "Replacement"}], "/.", 
         RowBox[{"Kn", "\[Rule]", "1"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["q", "3"], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "]"}], 
      "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.782625610550332*^9, 3.782625734866172*^9}, {
  3.782625773675314*^9, 3.782625789589219*^9}, {3.78262629248063*^9, 
  3.782626301132139*^9}, {3.782626602821877*^9, 3.782626612546958*^9}, {
  3.784117987644112*^9, 3.784117989980156*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"90cb03a5-f230-4c20-b768-3dcc7160bf8e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["EQq", "2"], "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"GetLHS", "[", 
             RowBox[{"1", ",", "1"}], "]"}], "+", 
            RowBox[{"GetLHS", "[", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}], "]"}]}], "\[Equal]", 
           RowBox[{
            RowBox[{"GetRHS", "[", 
             RowBox[{"1", ",", "1"}], "]"}], "+", 
            RowBox[{"GetRHS", "[", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}], "]"}]}]}], "/.", "Replacement"}], "/.", 
         RowBox[{"Kn", "\[Rule]", "1"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["q", "2"], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "]"}], 
      "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7826257669986277`*^9, 3.78262582859702*^9}, 
   3.782626149464203*^9, {3.7826261908485107`*^9, 3.782626191222742*^9}, {
   3.78262622767801*^9, 3.782626237782152*^9}, {3.782626616334536*^9, 
   3.782626622019244*^9}, 
   3.784117994759624*^9},ExpressionUUID->"8b1355d7-d625-4d20-9eb9-\
3ffd49b000f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["EQq", "1"], "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"GetLHS", "[", 
             RowBox[{"1", ",", "1"}], "]"}], "-", 
            RowBox[{"GetLHS", "[", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}], "]"}]}], "\[Equal]", 
           RowBox[{
            RowBox[{"GetRHS", "[", 
             RowBox[{"1", ",", "1"}], "]"}], "-", 
            RowBox[{"GetRHS", "[", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}], "]"}]}]}], "/.", "Replacement"}], "/.", 
         RowBox[{"Kn", "\[Rule]", "1"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["q", "1"], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "]"}], 
      "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.782625926606449*^9, 3.782625943663671*^9}, {
   3.782626077299472*^9, 3.782626078792904*^9}, {3.782626207487485*^9, 
   3.782626211831532*^9}, {3.7826262568743763`*^9, 3.78262627352564*^9}, {
   3.782626627853471*^9, 3.782626631696966*^9}, 
   3.784117998022225*^9},ExpressionUUID->"975d33a7-4cae-4078-afb5-\
3ed541e82db5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["EQ\[Sigma]", 
    RowBox[{"1", ",", "2"}]], "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"GetLHS", "[", 
             RowBox[{"2", ",", "2"}], "]"}], "-", 
            RowBox[{"GetLHS", "[", 
             RowBox[{"2", ",", 
              RowBox[{"-", "2"}]}], "]"}]}], "\[Equal]", 
           RowBox[{
            RowBox[{"GetRHS", "[", 
             RowBox[{"2", ",", "2"}], "]"}], "-", 
            RowBox[{"GetRHS", "[", 
             RowBox[{"2", ",", 
              RowBox[{"-", "2"}]}], "]"}]}]}], "/.", "Replacement"}], "/.", 
         RowBox[{"Kn", "\[Rule]", "1"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Sigma]", 
           RowBox[{"1", ",", "2"}]], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "]"}], 
      "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.782626086914935*^9, 3.782626097280197*^9}, 
   3.7826263182562637`*^9, {3.782626465490252*^9, 3.782626510587702*^9}, {
   3.782626635600184*^9, 3.782626643678496*^9}, 
   3.7841179994801817`*^9},ExpressionUUID->"e100b8f8-79ec-492e-b2cd-\
b173b7c86d80"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["EQ\[Sigma]", 
    RowBox[{"1", ",", "3"}]], "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"GetLHS", "[", 
             RowBox[{"2", ",", "1"}], "]"}], "-", 
            RowBox[{"GetLHS", "[", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}], "]"}]}], "\[Equal]", 
           RowBox[{
            RowBox[{"GetRHS", "[", 
             RowBox[{"2", ",", "1"}], "]"}], "-", 
            RowBox[{"GetRHS", "[", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}], "]"}]}]}], "/.", "Replacement"}], "/.", 
         RowBox[{"Kn", "\[Rule]", "1"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Sigma]", 
           RowBox[{"1", ",", "3"}]], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "]"}], 
      "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.782625947461657*^9, 3.7826259492180853`*^9}, {
   3.782626068310066*^9, 3.78262607203374*^9}, {3.782626162432078*^9, 
   3.7826261653207893`*^9}, {3.782626530483766*^9, 3.782626563480233*^9}, {
   3.782626649587304*^9, 3.7826266573049793`*^9}, 
   3.7841180010334263`*^9},ExpressionUUID->"b4470e5b-4350-43f6-87e6-\
b3245b6c08ac"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["EQ\[Sigma]", 
    RowBox[{"2", ",", "3"}]], "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"GetLHS", "[", 
             RowBox[{"2", ",", "1"}], "]"}], "+", 
            RowBox[{"GetLHS", "[", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}], "]"}]}], "\[Equal]", 
           RowBox[{
            RowBox[{"GetRHS", "[", 
             RowBox[{"2", ",", "1"}], "]"}], "+", 
            RowBox[{"GetRHS", "[", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}], "]"}]}]}], "/.", "Replacement"}], "/.", 
         RowBox[{"Kn", "\[Rule]", "1"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Sigma]", 
           RowBox[{"2", ",", "3"}]], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "]"}], 
      "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.782626579094285*^9, 3.782626585223968*^9}, {
   3.782626662729018*^9, 3.782626671929097*^9}, 
   3.7841180029829073`*^9},ExpressionUUID->"707afb2c-6446-442f-b8d1-\
1b436eb8793a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["EQ\[Sigma]", 
    RowBox[{"2", ",", "2"}]], "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"GetLHS", "[", 
             RowBox[{"2", ",", "2"}], "]"}], "+", 
            RowBox[{"GetLHS", "[", 
             RowBox[{"2", ",", 
              RowBox[{"-", "2"}]}], "]"}], "+", 
            RowBox[{
             SqrtBox[
              FractionBox["2", "3"]], 
             RowBox[{"GetLHS", "[", 
              RowBox[{"2", ",", "0"}], "]"}]}]}], "\[Equal]", 
           RowBox[{
            RowBox[{"GetRHS", "[", 
             RowBox[{"2", ",", "2"}], "]"}], "+", 
            RowBox[{"GetRHS", "[", 
             RowBox[{"2", ",", 
              RowBox[{"-", "2"}]}], "]"}], "+", 
            RowBox[{
             SqrtBox[
              FractionBox["2", "3"]], 
             RowBox[{"GetRHS", "[", 
              RowBox[{"2", ",", "0"}], "]"}]}]}]}], "/.", "Replacement"}], "/.", 
         RowBox[{"Kn", "\[Rule]", "1"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Sigma]", 
           RowBox[{"2", ",", "2"}]], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "]"}], 
      "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7826267250480843`*^9, 3.782626727345188*^9}, {
   3.782626761064494*^9, 3.7826268346214857`*^9}, 
   3.784118005080929*^9},ExpressionUUID->"88d50305-7c3f-4a6b-9760-\
cad3b93fc46f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["EQ\[Sigma]", 
    RowBox[{"1", ",", "1"}]], "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"GetLHS", "[", 
             RowBox[{"2", ",", "2"}], "]"}], "+", 
            RowBox[{"GetLHS", "[", 
             RowBox[{"2", ",", 
              RowBox[{"-", "2"}]}], "]"}], "-", 
            RowBox[{
             SqrtBox[
              FractionBox["2", "3"]], 
             RowBox[{"GetLHS", "[", 
              RowBox[{"2", ",", "0"}], "]"}]}]}], "\[Equal]", 
           RowBox[{
            RowBox[{"GetRHS", "[", 
             RowBox[{"2", ",", "2"}], "]"}], "+", 
            RowBox[{"GetRHS", "[", 
             RowBox[{"2", ",", 
              RowBox[{"-", "2"}]}], "]"}], "-", 
            RowBox[{
             SqrtBox[
              FractionBox["2", "3"]], 
             RowBox[{"GetRHS", "[", 
              RowBox[{"2", ",", "0"}], "]"}]}]}]}], "/.", "Replacement"}], "/.", 
         RowBox[{"Kn", "\[Rule]", "1"}]}], ",", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Sigma]", 
           RowBox[{"1", ",", "1"}]], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          SubscriptBox["x", "1"], ",", 
          SubscriptBox["x", "2"], ",", 
          SubscriptBox["x", "3"], ",", "t"}], "]"}]}], "]"}], 
      "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7826267250480843`*^9, 3.782626727345188*^9}, {
   3.782626761064494*^9, 3.782626861228861*^9}, 
   3.784118006558716*^9},ExpressionUUID->"d71db4c4-96ba-435f-89a3-\
75c758b51ad2"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1920, 1036},
WindowMargins->{{0, Automatic}, {0, Automatic}},
FrontEndVersion->"12.0 for Linux x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[422, 15, 225, 5, 99, "Title",ExpressionUUID->"35865585-77d2-4c26-9220-59b2954ea8cc"],
Cell[650, 22, 238, 6, 54, "Subtitle",ExpressionUUID->"4a972961-48c2-4909-bd05-2db5d26cc9a8"],
Cell[CellGroupData[{
Cell[913, 32, 154, 3, 68, "Section",ExpressionUUID->"a20515cf-e3bf-43e4-9c0d-a6757a2edae5"],
Cell[1070, 37, 263, 6, 36, "Text",ExpressionUUID->"96590df2-57ee-4122-a7a5-dde79ffae33c"],
Cell[1336, 45, 508, 10, 55, "Input",ExpressionUUID->"a140609c-9d39-45f5-bdb0-9fb8016a4905"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1881, 60, 160, 3, 68, "Section",ExpressionUUID->"a66729af-2c0b-420b-9a6e-cf7f341e4da8"],
Cell[2044, 65, 236, 6, 36, "Text",ExpressionUUID->"2c82af24-b88b-45d8-9ce7-1190cba18284"],
Cell[2283, 73, 6153, 185, 396, "Input",ExpressionUUID->"08cc1a2f-7b16-402e-b24e-0a2f718ebcae"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8473, 263, 546, 16, 71, "Section",ExpressionUUID->"bb0b5523-a811-4b15-8323-b5e2d61b2056"],
Cell[9022, 281, 601, 18, 38, "Text",ExpressionUUID->"3851b178-07af-4768-bf4b-610e3d063db6"],
Cell[9626, 301, 7478, 217, 269, "Input",ExpressionUUID->"bb9287e9-b64e-4673-9b97-d21bf520a1da"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17141, 523, 251, 4, 68, "Section",ExpressionUUID->"11d9809b-e0e7-4f50-8bb6-72578920e083"],
Cell[17395, 529, 539, 11, 60, "Text",ExpressionUUID->"4949c295-f853-48eb-a1e8-6cfec7a23197"],
Cell[CellGroupData[{
Cell[17959, 544, 435, 14, 63, "Subsection",ExpressionUUID->"832ccca0-7855-442a-b680-b4dd774c1661"],
Cell[18397, 560, 8488, 237, 242, "Input",ExpressionUUID->"5828cf1c-362f-42ef-a902-4933bedf82ae"],
Cell[26888, 799, 12437, 295, 870, "Input",ExpressionUUID->"869298bb-6eef-4119-9976-5657b3385d42"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39362, 1099, 340, 9, 55, "Subsection",ExpressionUUID->"dd409798-f00e-418c-93a9-c6dc37e2ef23"],
Cell[39705, 1110, 20706, 517, 1048, "Input",ExpressionUUID->"dad0f3af-a9a7-4717-af20-3352aa5f4f35"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60448, 1632, 268, 4, 55, "Subsection",ExpressionUUID->"0fbd4a14-e937-4df9-b821-a2071547fcdd"],
Cell[60719, 1638, 10946, 287, 823, "Input",ExpressionUUID->"fcd8fb56-2fed-472e-bff5-0587af1e0046"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[71714, 1931, 269, 4, 68, "Section",ExpressionUUID->"75fd2d51-0253-4600-b328-5ba9b0de2b18"],
Cell[71986, 1937, 3534, 92, 383, "Input",ExpressionUUID->"ab8e8502-79ac-4527-9adc-62d06e53750a"],
Cell[CellGroupData[{
Cell[75545, 2033, 166, 3, 55, "Subsection",ExpressionUUID->"79d2130d-cac2-4c78-a525-c9e093f61848"],
Cell[75714, 2038, 627, 17, 31, "Input",ExpressionUUID->"c0c12798-ddc0-40ad-a563-27c006022168"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[76390, 2061, 226, 4, 68, "Section",ExpressionUUID->"898aa40e-e33d-4352-8e10-34afb21d2190"],
Cell[CellGroupData[{
Cell[76641, 2069, 168, 3, 55, "Subsection",ExpressionUUID->"eb29aa3a-c0ba-4cb1-90bc-bb3f217ddf79"],
Cell[76812, 2074, 4499, 105, 328, "Input",ExpressionUUID->"c47755fa-7e3e-49db-945c-b9f708f7ae52"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81348, 2184, 533, 16, 57, "Subsection",ExpressionUUID->"99ae5e9d-0bad-45b5-8470-fc118b60a607"],
Cell[81884, 2202, 7889, 205, 420, "Input",ExpressionUUID->"f4211b57-0e51-4ea1-8b29-9f7d6d323e3d"],
Cell[89776, 2409, 3748, 95, 272, "Input",ExpressionUUID->"850e80a0-b70d-4bf5-a9ea-9e137b652f02"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93561, 2509, 492, 14, 55, "Subsection",ExpressionUUID->"99190ba9-6f4d-4fc5-b177-e5d4264d4719"],
Cell[94056, 2525, 10997, 302, 453, "Input",ExpressionUUID->"8306fb79-78de-4217-bbe7-4b24d33cc76e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105090, 2832, 923, 29, 61, "Subsection",ExpressionUUID->"b62671fd-0a73-4fe3-a933-73a48e4cc93a"],
Cell[106016, 2863, 541, 14, 43, "Text",ExpressionUUID->"88d56226-de62-4641-9e4a-4e5dfc53e587"],
Cell[106560, 2879, 3183, 79, 257, "Input",ExpressionUUID->"6e6247ce-d184-4547-9cb7-7bd7f4e4e8f4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[109780, 2963, 164, 3, 55, "Subsection",ExpressionUUID->"543d9f4f-8ac6-450c-8b3a-6d13b7334546"],
Cell[109947, 2968, 580, 16, 31, "Input",ExpressionUUID->"7b261c18-3cbf-4d97-b3de-402dc0d186cd"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[110576, 2990, 222, 4, 68, "Section",ExpressionUUID->"9dcad94b-2e57-4e4a-a066-08af6a467087"],
Cell[110801, 2996, 255, 6, 36, "Text",ExpressionUUID->"6ee8e014-e9f1-4272-ac0d-12447566ce20"],
Cell[CellGroupData[{
Cell[111081, 3006, 166, 3, 55, "Subsection",ExpressionUUID->"12f4994d-514f-4a20-ab7a-c69ba3404a69"],
Cell[111250, 3011, 12484, 340, 265, "Input",ExpressionUUID->"d42f9a67-c252-4a4f-ae99-18953a7b8a84"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123771, 3356, 717, 20, 61, "Subsection",ExpressionUUID->"fc07b21c-94bc-4a15-99d4-961b9b8266cc"],
Cell[124491, 3378, 4062, 90, 272, "Input",ExpressionUUID->"4ea5055d-d309-4bd4-988a-debba3eb7159"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128590, 3473, 413, 12, 61, "Subsection",ExpressionUUID->"2eaf4bdb-c8ce-4823-87ba-f203fd80f72d"],
Cell[129006, 3487, 3513, 85, 328, "Input",ExpressionUUID->"877d107f-fc47-4699-9446-5fb7b8a5f17c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[132556, 3577, 556, 16, 57, "Subsection",ExpressionUUID->"68cd4330-e332-4f60-94df-0616830bb444"],
Cell[133115, 3595, 14448, 348, 578, "Input",ExpressionUUID->"161ab294-19bc-4e35-9f7f-824744ea1a87"],
Cell[147566, 3945, 3876, 99, 272, "Input",ExpressionUUID->"c3a568b3-a2b8-404c-bfa6-8fa1492c778e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[151491, 4050, 227, 4, 68, "Section",ExpressionUUID->"b04d69b8-ee85-4ea1-8f51-e3a0f47c6016"],
Cell[151721, 4056, 381, 8, 36, "Text",ExpressionUUID->"fa02948b-0b46-4915-9399-5c0cd9b5c8fb"],
Cell[152105, 4066, 6673, 171, 213, "Input",ExpressionUUID->"1281625e-3613-45fb-b8cd-59057eebc33c"],
Cell[CellGroupData[{
Cell[158803, 4241, 167, 3, 55, "Subsection",ExpressionUUID->"c7552653-0108-4396-b1e7-63b67872d614"],
Cell[CellGroupData[{
Cell[158995, 4248, 5027, 132, 151, "Input",ExpressionUUID->"b155bd09-7c80-4e80-acba-d0fe196ef372"],
Cell[164025, 4382, 2827, 84, 85, "Output",ExpressionUUID->"13b76c48-7831-4ced-bcba-ca5e778d2af1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[166889, 4471, 4701, 128, 151, "Input",ExpressionUUID->"3e005c1c-7049-45d5-a1eb-7ea719a60477"],
Cell[171593, 4601, 3300, 98, 85, "Output",ExpressionUUID->"3d6b97c0-2433-4905-9a01-fd49db9fe597"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[174942, 4705, 159, 3, 55, "Subsection",ExpressionUUID->"b48b8e3a-2328-45c0-8fd1-78ec6861876c"],
Cell[175104, 4710, 8042, 222, 197, "Input",ExpressionUUID->"c0cd7ab8-0fe5-4df2-a617-6cebc09d1b6c"],
Cell[183149, 4934, 1333, 35, 39, "Input",ExpressionUUID->"90cb03a5-f230-4c20-b768-3dcc7160bf8e"],
Cell[184485, 4971, 1601, 44, 39, "Input",ExpressionUUID->"8b1355d7-d625-4d20-9eb9-3ffd49b000f4"],
Cell[186089, 5017, 1624, 44, 39, "Input",ExpressionUUID->"975d33a7-4cae-4078-afb5-3ed541e82db5"],
Cell[187716, 5063, 1624, 45, 39, "Input",ExpressionUUID->"e100b8f8-79ec-492e-b2cd-b173b7c86d80"],
Cell[189343, 5110, 1701, 46, 39, "Input",ExpressionUUID->"b4470e5b-4350-43f6-87e6-b3245b6c08ac"],
Cell[191047, 5158, 1550, 44, 39, "Input",ExpressionUUID->"707afb2c-6446-442f-b8d1-1b436eb8793a"],
Cell[192600, 5204, 1898, 54, 58, "Input",ExpressionUUID->"88d50305-7c3f-4a6b-9760-cad3b93fc46f"],
Cell[194501, 5260, 1896, 54, 58, "Input",ExpressionUUID->"d71db4c4-96ba-435f-89a3-75c758b51ad2"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

